@@ -296,14 +296,14 @@ unsigned TablePosStart;
     "/*Do not edit this file. It is automatically generated.*/\n"
     "\n"
     "#ifdef __Limited_Proc_Size\n"
-    " char *BorlandCPPIsShit(WORD wchar, TconvertedPass1 *cq);\n"
-    " char *BorlandCPPIsShit2(WORD wchar, TconvertedPass1 *cq);\n"
+    " char *BorlandCPPIsShit(uint16_t wchar, TconvertedPass1 *cq);\n"
+    " char *BorlandCPPIsShit2(uint16_t wchar, TconvertedPass1 *cq);\n"
     "#endif\n"
     "\n"
     "extern const char *SimpleTable[];\n"
    "\n"
     "/*This function expands an extended WP character into LaTEX sequence*/\n"
-    "const char *Ext_chr_str(WORD wchar_code, TconvertedPass1 *cq, const CpTranslator *ConvertCP)\n"
+    "const char *Ext_chr_str(uint16_t wchar_code, TconvertedPass1 *cq, const CpTranslator *ConvertCP)\n"
     "{\n"
     "#ifdef DEBUG\n"
     "  fprintf(cq->log,\"\\n#Ext_chr_str(0x%%X) \",wchar_code);fflush(cq->log);\n"
@@ -312,14 +312,14 @@ unsigned TablePosStart;
     "  //if(ConvertCP==NULL) ConvertCP=cq->ConvertCpg;\n"
     " if(ConvertCP!=NULL)	/*Translate other character sets*/\n"
     "	{\n"
-    "	WORD WC2 = (*ConvertCP)[wchar_code];\n"
+    "	uint16_t WC2 = (*ConvertCP)[wchar_code];\n"
     "	if(WC2==0) return(\" -?- \");\n"
     "	wchar_code=WC2;\n"
     "	}\n"
     "\n"
     " if(Convert2Target!=NULL)\n"
     "   {\n"
-    "   WORD unicode;\n"
+    "   uint16_t unicode;\n"
     "   switch(OutCodePage)\n"
     "     {\n"
     "     case UTF8: unicode = (*Convert2Target)[wchar_code];\n"
@@ -368,7 +368,7 @@ unsigned TablePosStart;
        "#ifdef __Limited_Proc_Size\n"
        "       }\n"
        "return(BorlandCPPIsShit(wchar_code,cq));}\n"
-       "char *BorlandCPPIsShit(WORD wchar_code, TconvertedPass1 *cq)\n"
+       "char *BorlandCPPIsShit(uint16_t wchar_code, TconvertedPass1 *cq)\n"
        "{switch(wchar_code) {\n"
        "#endif\n"
        "\n");
@@ -378,7 +378,7 @@ unsigned TablePosStart;
        "#ifdef __Limited_Proc_Size\n"
        "       }\n"
        "return(BorlandCPPIsShit2(wchar_code,cq));}\n"
-       "char *BorlandCPPIsShit2(WORD wchar_code, TconvertedPass1 *cq)\n"
+       "char *BorlandCPPIsShit2(uint16_t wchar_code, TconvertedPass1 *cq)\n"
        "{switch(wchar_code) {\n"
        "#endif\n"
        "\n");
@@ -467,7 +467,8 @@ FILE *Fper;
      }     
    }
    fclose(Fper);	// Second file is different must be replaced.   
-   remove(FileName2());		// Unlink older persistent name.
+   if(remove(FileName2()))		// Unlink older persistent name.
+       printf("Cannot remove file \"%s\"!\n", FileName2());
  }
 
  if(Ftmp) {fclose(Ftmp);Ftmp=NULL;}
@@ -516,7 +517,7 @@ FILE *F;
 codepage internal;
 codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1276, cpkam,
          cpwp4a, cpwp5, cpwp5_cz, cpwp6,
-	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4,
+	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4, iso_8859_5,
          unicode,koi8cs,koi8r,
 	 mtef2,
          MAC_ROMAN;
@@ -526,7 +527,7 @@ codepage symbol, Wingdings;
 doublelist llHTML;
 string FileName;
 
- puts("<<<cplib>>> (c)1999-2022 J.Fojtik");
+ puts("<<<cplib>>> (c)1999-2023 J.Fojtik");
 
  if(argc>1)
    {
@@ -610,6 +611,8 @@ string FileName;
  if(iso_8859_3.name) {free(iso_8859_3.name);iso_8859_3.name=strdup("iso_8859_3");}
  LoadCodePage("is8859_4",iso_8859_4,0);
  if(iso_8859_4.name) {free(iso_8859_4.name);iso_8859_4.name=strdup("iso_8859_4");}
+ LoadCodePage("is8859_5",iso_8859_5,0);
+ if(iso_8859_5.name) {free(iso_8859_5.name);iso_8859_5.name=strdup("iso_8859_5");}
 
 
  //if(heapcheck()<=0)
@@ -682,6 +685,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
  BuildTranslator(iso_8859_2,internal,F);	iso_8859_2.Erase();
  BuildTranslator(iso_8859_3,internal,F);	iso_8859_3.Erase();
  BuildTranslator(iso_8859_4,internal,F);	iso_8859_4.Erase();
+ BuildTranslator(iso_8859_5,internal,F);	iso_8859_5.Erase();
 
  BuildTranslator(cp852,internal,F);		cp852.Erase();
  BuildTranslator(cp1250,internal,F);		cp1250.Erase();
