@@ -154,8 +154,8 @@ void NotR(char *R, int size)	//R1:=not(R1)
 {
   while(size>=4)
   {
-    *(DWORD*)R = ~ *(DWORD*)R;
-    R += sizeof(DWORD*);
+    *(uint32_t*)R = ~ *(uint32_t*)R;
+    R += sizeof(uint32_t*);
     size -= 4;
   }
   while(size-->0)
