@@ -39,14 +39,18 @@
  #define SupportCSV 2	//Read procedure only
  #define SupportDIB 2
  #define SupportFITS 2	//Read procedure only
+ #define SupportGIF 2
  #define SupportICO 2	//Read procedure only
  #define SupportMAT 2	//Read procedure only
  #define SupportOKO 2	//Read procedure only
  #define SupportPCX 2	//Read procedure only
  #define SupportRAS 2	//Read procedure only
+ #define SupportRAS_SUN 2
  #define SupportRAW 2	//Read procedure only
  #define SupportTGA 2	//Read procedure only
+ #define SupportTIFF 2
  #define SupportTXT 2	//Read procedure only
+ #define SupportTXTgm 2
  #define SupportWMF 2
  #define SupportWPG 1	//Compile only supporting stub, build-in reader included
  #define SupportXPM 2
@@ -133,10 +137,10 @@
 
 
 #ifndef SupportJPG
-  #define SupportJPG  10
+  #define SupportJPG  2
 #endif
 #ifndef SupportPNG
-  #define SupportPNG  10
+  #define SupportPNG  2
 #endif
 
 #ifndef SupportFTG
