@@ -15,7 +15,7 @@
 
 #include "typedfs.h"
 #include "common.h"
-#include "raster.h"
+#include "image.h"
 #include "img_tool.h"
 #include "ras_prot.h"
 #include "std_str.h"
@@ -37,14 +37,14 @@ typedef struct
 	{
 	char SignatureMain[3];
 	char SignatureRelease[3];
-	WORD Width, Height;
-	BYTE Flag, BackGround, Aspect;
+	uint16_t Width, Height;
+	uint8_t Flag, BackGround, Aspect;
 	} TypeGIFHeader;
 
 typedef struct
 	{
-	WORD Left, Top, Width, Height;
-	BYTE Flag;	//Local Color Table Flag 1 Bit; Interlace Flag 1 Bit; Sort Flag 1 Bit; Reserved 2 Bits; Size of Local Color Table 3 Bits
+	uint16_t Left, Top, Width, Height;
+	uint8_t Flag;	//Local Color Table Flag 1 Bit; Interlace Flag 1 Bit; Sort Flag 1 Bit; Reserved 2 Bits; Size of Local Color Table 3 Bits
 	} TypeGIFImageDescriptor;
 
 
@@ -73,36 +73,36 @@ return(loadstruct(f,"wwwwb",
 
 class ABitStream
 	{
-public: BYTE *ptr;
-	BYTE *RealBufStart, *BufEnd;
-	DWORD BitBuf;
-	WORD BufSize;
-	BYTE BitPos;
+public: uint8_t *ptr;
+	uint8_t *RealBufStart, *BufEnd;
+	uint32_t BitBuf;
+	uint16_t BufSize;
+	uint8_t BitPos;
 
 	long FileLeft;
 	FILE *f;
 
-	//BYTE *BufPhysEnd;
-	BYTE m;
-	BYTE n;
+	//uint8_t *BufPhysEnd;
+	uint8_t m;
+	uint8_t n;
 
-	void InitBitStream(void *p, WORD NewBufSize, FILE *file, long fsize);
-	WORD Read_N(BYTE BitCount);
+	void InitBitStream(void *p, uint16_t NewBufSize, FILE *file, long fsize);
+	uint16_t Read_N(uint8_t BitCount);
 	virtual void RdFromFile(void)=0;	// Load bits from GIF file
 	};
 
 //This procedure make initialization of the bit stream
-void ABitStream::InitBitStream(void *p, WORD NewBufSize, FILE *file, long fsize)
+void ABitStream::InitBitStream(void *p, uint16_t NewBufSize, FILE *file, long fsize)
 {
 //----------------------}
   m = 0x01;
-  //BufPhysEnd = (BYTE *)p+BufSize-1;
+  //BufPhysEnd = (uint8_t *)p+BufSize-1;
   n=0;
 //---------------------}
   FileLeft = fsize;
-  BufSize = NewBufSize & ~(WORD)1;
-  RealBufStart = (BYTE *)p;
-  ptr = (BYTE *)p;
+  BufSize = NewBufSize & ~(uint16_t)1;
+  RealBufStart = (uint8_t *)p;
+  ptr = (uint8_t *)p;
   *RealBufStart = 0;
   BufEnd = RealBufStart;
   BitPos = 32;
@@ -111,11 +111,11 @@ void ABitStream::InitBitStream(void *p, WORD NewBufSize, FILE *file, long fsize)
 }
 
 /** This procedure reads n bits from the bit stream. */
-WORD ABitStream::Read_N(BYTE BitCount)
+uint16_t ABitStream::Read_N(uint8_t BitCount)
 {
-static const WORD bmsk[17]={0x0,0x1,0x3,0x7,0xF,0x1F,0x3F,0x7F,0xFF,
+static const uint16_t bmsk[17]={0x0,0x1,0x3,0x7,0xF,0x1F,0x3F,0x7F,0xFF,
 		     0x1FF,0x3FF,0x7FF,0xFFF,0x1FFF,0x3FFF,0x7FFF,0xFFFF};
-WORD u;
+uint16_t u;
 
  if(BitPos+BitCount>=32)
  {
@@ -123,7 +123,7 @@ WORD u;
    {
      BitBuf = BitBuf >> 8;
      BitPos -= 8;
-     BitBuf |= ( (DWORD)(*(BYTE*)ptr) << 24 );
+     BitBuf |= ( (uint32_t)(*(uint8_t*)ptr) << 24 );
      ptr++;
      if(BitPos+BitCount>=32) 
        goto MustReadChunk;	// Byte added is not sufficient enough.
@@ -138,12 +138,12 @@ MustReadChunk:
        RdFromFile();
      }
 #ifdef HI_ENDIAN
-     BitBuf |= ( (DWORD)(*(BYTE *)ptr) << 16 );
+     BitBuf |= ( (uint32_t)(*(uint8_t *)ptr) << 16 );
      ptr++;
-     BitBuf |= ( (DWORD)(*(BYTE *)ptr) << 24 );
+     BitBuf |= ( (uint32_t)(*(uint8_t *)ptr) << 24 );
      ptr++;
 #else
-     BitBuf |= ( (DWORD)(*(WORD *)ptr) << 16 );
+     BitBuf |= ( (uint32_t)(*(uint16_t *)ptr) << 16 );
      ptr+=2;
 #endif
    }
@@ -160,8 +160,8 @@ public: virtual void RdFromFile(void);	// Load bits from GIF file
 
 void GIFBitStream::RdFromFile(void)		// Load bits from GIF file
 {
-BYTE len;
-WORD ReadedB;
+uint8_t len;
+uint16_t ReadedB;
 
  ReadedB = 0;
 
@@ -191,7 +191,7 @@ WORD ReadedB;
 }
 
 
-void Add2Pixel(Raster2DAbstract *Raster, WORD Value, WORD &x, WORD &y, int &Interlace)
+void Add2Pixel(Raster2DAbstract *Raster, uint16_t Value, uint16_t &x, uint16_t &y, int &Interlace)
 {
  if(!Raster) return;
  Raster->SetValue2D(x,y,Value);
@@ -237,14 +237,14 @@ void Add2Pixel(Raster2DAbstract *Raster, WORD Value, WORD &x, WORD &y, int &Inte
 
 Image LoadPictureGIF(const char *Name)
 {
-BYTE *OutCode=NULL;
-WORD *Prefix=NULL,*Suffix=NULL;
-WORD Nacteno;
+uint8_t *OutCode=NULL;
+uint16_t *Prefix=NULL,*Suffix=NULL;
+uint16_t Nacteno;
 FILE *f;
 Image Img,*CurrImg;
-WORD InCode,OldCode,CurCode,Code,ClearCode,OutCount,FirstFree,FreeCode,EOFCode,MaxCode;
-BYTE FinChar,BitMask,CodeSize,InitCodeSize;
-WORD X,Y;
+uint16_t InCode,OldCode,CurCode,Code,ClearCode,OutCount,FirstFree,FreeCode,EOFCode,MaxCode;
+uint8_t FinChar,BitMask,CodeSize,InitCodeSize;
+uint16_t X,Y;
 int Interlace;
 TypeGIFHeader GIFHeader;
 TypeGIFImageDescriptor GIFImageDescriptor;
@@ -280,10 +280,10 @@ int I;
   }
   /*?-Global Color Map*/
 
-  if((OutCode=(BYTE *)malloc(4096))==NULL) goto FINISH;
-  if((CompBuffer=(BYTE *)malloc(GIFBufSize))==NULL) goto FINISH;
-  if((Prefix=(WORD *)calloc(4096,sizeof(WORD)))==NULL) goto FINISH;
-  if((Suffix=(WORD *)calloc(4096,sizeof(WORD)))==NULL) goto FINISH;
+  if((OutCode=(uint8_t *)malloc(4096))==NULL) goto FINISH;
+  if((CompBuffer=(uint8_t *)malloc(GIFBufSize))==NULL) goto FINISH;
+  if((Prefix=(uint16_t *)calloc(4096,sizeof(uint16_t)))==NULL) goto FINISH;
+  if((Suffix=(uint16_t *)calloc(4096,sizeof(uint16_t)))==NULL) goto FINISH;
 
   while(!feof(f))
     {
@@ -422,11 +422,11 @@ int I;
 		CurrImg->Next=new Image;
 		CurrImg=CurrImg->Next;
 		}
-	CurrImg->x=GIFImageDescriptor.Left/5.0;
-//	CurrImg->y=(GIFHeader.Height-GIFImageDescriptor.Top-GIFImageDescriptor.Height)/5.0;
-	CurrImg->y=(GIFImageDescriptor.Height)/5.0;
-	CurrImg->dx=GIFImageDescriptor.Width/5.0;
-	CurrImg->dy=GIFImageDescriptor.Height/5.0;
+	CurrImg->x = GIFImageDescriptor.Left/5.0f;
+//	CurrImg->y = (GIFHeader.Height-GIFImageDescriptor.Top-GIFImageDescriptor.Height)/5.0f;
+	CurrImg->y = (GIFImageDescriptor.Height)/5.0f;
+	CurrImg->dx = GIFImageDescriptor.Width/5.0f;
+	CurrImg->dy = GIFImageDescriptor.Height/5.0f;
 	if(Raster!=NULL) {CurrImg->AttachRaster(Raster);Raster=NULL;}
 	if(LocalPalette) {CurrImg->AttachPalette(LocalPalette);LocalPalette=NULL;}
 		    else if(Palette!=NULL){CurrImg->AttachPalette(Palette);}
@@ -464,7 +464,7 @@ FINISH:
 /** Calculates number of bits needed to store numbers between 0 and n - 1
  * @param[in]	n	Number of numbers to store (0 to n - 1)
  * @return	Number of bits needed */
-static int BitsNeeded(WORD n)
+static int BitsNeeded(uint16_t n)
 {
 int ret = 1;
 
@@ -499,8 +499,8 @@ static int StoreGIFHeader(FILE *f, const Image &Img, APalette *GlobPalette=NULL)
   int NumColors = 1 << Img.Raster->GetPlanes();
   if(GlobPalette) NumColors = GlobPalette->Size1D;
  
-  WORD GlobalColorTableSize;
-  //BYTE GlobalColorTableFlag;
+  uint16_t GlobalColorTableSize;
+  //uint8_t GlobalColorTableFlag;
   if(NumColors>0)
   {
     NumColors = 1 << BitsNeeded(NumColors);
@@ -513,7 +513,7 @@ static int StoreGIFHeader(FILE *f, const Image &Img, APalette *GlobPalette=NULL)
     //GlobalColorTableFlag = 0;
   }
 
-  BYTE Flag =  (Img.Raster->GetPlanes() << 4) |
+  uint8_t Flag =  (Img.Raster->GetPlanes() << 4) |
 		// Sort Flag = 0
 	      (GlobalColorTableSize & 0x7);
   if(GlobPalette != NULL)
@@ -565,11 +565,11 @@ public:
    FILE *OutFile;
    Raster2DAbstract *Ras;
    int codesize;
-   BYTE Buffer[256];		/**< There must be one to much !!! */
+   uint8_t Buffer[256];		/**< There must be one to much !!! */
    int  Index;			/**< Current byte in buffer */
    int BitsLeft;		/**< Bits left to fill in current byte. These are right-justified */
-   BYTE *StrChr;
-   WORD *StrNxt,
+   uint8_t *StrChr;
+   uint16_t *StrNxt,
         *StrHsh,
         NumStrings;
 
@@ -578,17 +578,17 @@ public:
    void FreeStrtab(void);
    int AllocStrtab(void);
    void ClearStrtab(int codesize);
-   WORD AddCharString(WORD index, BYTE b);
+   uint16_t AddCharString(uint16_t index, uint8_t b);
    int WriteBits(int bits, int numbits);
-   WORD FindCharString(WORD index, BYTE b);
+   uint16_t FindCharString(uint16_t index, uint8_t b);
    int ResetOutBitFile(void);
 
-   WORD X, Y;
+   uint16_t X, Y;
    int inputbyte(void);
 
    //FILE *DebugF;
 
-   inline int WriteByte(BYTE b)
+   inline int WriteByte(uint8_t b)
    {
      if (putc(b, OutFile) == EOF)
         return GIF_ERRWRITE;
@@ -603,20 +603,20 @@ public:
      *            GIF_ERRWRITE - Error writing to the file. */
     inline int Write(const void *buf, unsigned len)
     {
-      if(fwrite(buf, sizeof(BYTE), len, OutFile) < len)
+      if(fwrite(buf, sizeof(uint8_t), len, OutFile) < len)
         return GIF_ERRWRITE;
       return GIF_OK;
     }
 
-   static const WORD MAXBITS = 12;
-   static const WORD MAXSTR = (1 << MAXBITS);
+   static const uint16_t MAXBITS = 12;
+   static const uint16_t MAXSTR = (1 << MAXBITS);
 
-   static const WORD HASHSIZE = 9973;
-   static const WORD HASHSTEP = 2039;
+   static const uint16_t HASHSIZE = 9973;
+   static const uint16_t HASHSTEP = 2039;
 
-   static const WORD HASH_FREE = 0xFFFF;
-   static const WORD RES_CODES = 2;
-   static const WORD NEXT_FIRST = 0xFFFF;
+   static const uint16_t HASH_FREE = 0xFFFF;
+   static const uint16_t RES_CODES = 2;
+   static const uint16_t NEXT_FIRST = 0xFFFF;
 };
 
 
@@ -649,17 +649,17 @@ int WbitStream::AllocStrtab(void)
     /* Just in case . . . */
   FreeStrtab();
 
-  if((StrChr = (BYTE *)malloc(MAXSTR * sizeof(BYTE))) == 0) {
+  if((StrChr = (uint8_t *)malloc(MAXSTR * sizeof(uint8_t))) == 0) {
         FreeStrtab();
         return -1;
   }
 
-  if((StrNxt = (WORD*) malloc(MAXSTR * sizeof(WORD))) == 0) {
+  if((StrNxt = (uint16_t*) malloc(MAXSTR * sizeof(uint16_t))) == 0) {
         FreeStrtab();
         return -1;
   }
 
-  if ((StrHsh = (WORD*) malloc(HASHSIZE * sizeof(WORD))) == 0) {
+  if ((StrHsh = (uint16_t*) malloc(HASHSIZE * sizeof(uint16_t))) == 0) {
         FreeStrtab();
         return -1;
   }
@@ -695,9 +695,9 @@ void WbitStream::FreeStrtab(void)
  * @param[in] index  Index to first part of string, or 0xFFFF is only 1 byte is wanted
  * @param[in] b     Last byte in new string
  * @return Index to new string, or 0xFFFF if no more room */
-WORD WbitStream::AddCharString(WORD index, BYTE b)
+uint16_t WbitStream::AddCharString(uint16_t index, uint8_t b)
 {
-  WORD hshidx;
+  uint16_t hshidx;
 
 
     /*
@@ -730,7 +730,7 @@ WORD WbitStream::AddCharString(WORD index, BYTE b)
 void WbitStream::ClearStrtab(int codesize)
 {
   int q, w;
-  WORD *wp;
+  uint16_t *wp;
 
 
     /*
@@ -763,9 +763,9 @@ void WbitStream::ClearStrtab(int codesize)
  *                          only 1 byte is wanted
  *                  b     - Last byte in string
  *  RETURNS:        Index to string, or 0xFFFF if not found */
-WORD WbitStream::FindCharString(WORD index, BYTE b)
+uint16_t WbitStream::FindCharString(uint16_t index, uint8_t b)
 {
-    WORD hshidx, nxtidx;
+    uint16_t hshidx, nxtidx;
 
 
     /*
@@ -798,9 +798,9 @@ WORD WbitStream::FindCharString(WORD index, BYTE b)
 int WbitStream::LZW_Compress(void)
 {
   int c;
-  WORD index;
+  uint16_t index;
   int  clearcode, endofinfo, numbits, limit, errcode;
-  WORD prefix = 0xFFFF;
+  uint16_t prefix = 0xFFFF;
 
 	/* Set up the given outfile */
   InitBitFile();
@@ -887,7 +887,7 @@ int WbitStream::LZW_Compress(void)
  *  RETURNS:        0 - OK, -1 - error */
 int WbitStream::ResetOutBitFile(void)
 {
-    BYTE numbytes;
+    uint8_t numbytes;
 
 
     /*
@@ -920,7 +920,7 @@ int WbitStream::ResetOutBitFile(void)
 int WbitStream::WriteBits(int bits, int numbits)
 {
   int  bitswritten = 0;
-  BYTE numbytes = 255;
+  uint8_t numbytes = 255;
 
   //if(DebugF) fprintf(DebugF,"%u(%u) X=%u; Y=%u\n", bits, numbits, X, Y);
 
@@ -988,8 +988,22 @@ bool NeedLocalPalette = false;
   {
     if(Img.Palette!=NULL)
     {
-      GlobPalette = Img.Palette;
-      GlobPalette->UsageCount++;
+      if(Img.Palette->GetPlanes()!=24 || Img.Palette->Channels()!=3)	// Need 3channels RGB 8 bit.
+      {
+        GlobPalette = BuildPalette(1<<Img.Raster->GetPlanes(), 8);
+        //Img.Palette->Set(*GlobPalette);  //does not work.
+        for(int i=0; i<GlobPalette->Size1D; i++)
+        {
+          RGBQuad RGB;
+          Img.Palette->Get(i,&RGB);
+          GlobPalette->Set(i,&RGB);
+        }
+      }
+      else
+      {
+        GlobPalette = Img.Palette;
+        GlobPalette->UsageCount++;
+      }
     }
     else
     {
@@ -1034,7 +1048,7 @@ bool NeedLocalPalette = false;
     ID.Flag = 0;
     if(NeedLocalPalette)
     {
-      WORD NumColors = 1 << Img.Raster->GetPlanes();
+      uint16_t NumColors = 1 << Img.Raster->GetPlanes();
       GlobPalette = Img.Palette;
       if(GlobPalette!=NULL)
       {
@@ -1049,7 +1063,7 @@ bool NeedLocalPalette = false;
           FillGray(GlobPalette);
         }
       }
-      WORD LocalColorTableSize;
+      uint16_t LocalColorTableSize;
       if(NumColors>0)
       {
         NumColors = 1 << BitsNeeded(NumColors);
@@ -1063,7 +1077,7 @@ bool NeedLocalPalette = false;
     SaveGIFImageDescriptor(f,ID);
     if((ID.Flag & 0x80)>0)			/*Local Color Map*/
     {
-      WORD LocalColorTableSize = (unsigned)2 << (ID.Flag & 7);
+      uint16_t LocalColorTableSize = (unsigned)2 << (ID.Flag & 7);
       if(GlobPalette->Size1D >= LocalColorTableSize)
         fwrite(GlobPalette->Data1D,3,LocalColorTableSize,f);
       else
