@@ -9,7 +9,7 @@
 #include <string.h>
 
 #include "typedfs.h"
-#include "raster.h"
+#include "image.h"
 #include "struct.h"
 
 #include "imgsupp.h"
@@ -52,7 +52,7 @@ static int read_user_chunk_callback(png_struct *ping, png_unknown_chunkp chunk)
       if(PropExif->Data==NULL) {delete PropExif; return 0;}
       PropExif->DataSize = chunk->size;
       unsigned char *p = (unsigned char *)PropExif->Data;
-      for(DWORD ptr=0; ptr<chunk->size; ptr++)
+      for(uint32_t ptr=0; ptr<chunk->size; ptr++)
         *p++ = *s++;
       PropExif->Name = "Exif";
       Img->AttachProperty(PropExif);
@@ -62,84 +62,47 @@ static int read_user_chunk_callback(png_struct *ping, png_unknown_chunkp chunk)
 }
 
 
-/// TODO: This function is not finished.
-Raster2DAbstract *LoadFragmentPNG(FILE *F)
+void LoadFragmentPNG(FILE *F, Image *Img)
 {
-//png_structp png_ptr;
-//png_infop info_ptr;
-
-  if(F==NULL) return NULL;
-/*
-  png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
-  if(!png_ptr) return NULL;
-
-  info_ptr = png_create_info_struct(png_ptr);
-  if(!info_ptr) goto FINISH;	// [read_png_file] png_create_info_struct failed
-
-  if(setjmp(png_jmpbuf(png_ptr))) goto FINISH;	// [read_png_file] Error during init_io
-
-  png_init_io(png_ptr, F);
-
-
-FINISH:
-  png_destroy_read_struct(&png_ptr, &info_ptr, png_infopp_NULL);
-*/
-  return NULL;
-}
-
-
-Image LoadPicturePNG(const char *Name)
-{
-Image Img;
-png_byte header[8];			// 8 is the maximum size that can be checked
 Raster2DAbstract *Raster = NULL;
 APalette *Palette = NULL;
-FILE *f;
-png_structp png_ptr = NULL;
-png_infop info_ptr = NULL;
+png_structp png_ptr;
+png_infop info_ptr;
 png_colorp palette;
 int num_palette;
-png_byte color_type;
-int number_of_passes;
 int i;
 
-  if((f=fopen(Name,"rb"))==NULL) return(Img);
+  if(F==NULL) return;
 
-  fread(header, 1, 8, f);
-  if(png_sig_cmp(header, 0, 8)) goto FINISH;
-
-	/* initialize stuff */
   png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
-	
-  if(!png_ptr) goto FINISH;	// [read_png_file] png_create_read_struct failed
+  if(!png_ptr) return;
 
   info_ptr = png_create_info_struct(png_ptr);
   if(!info_ptr) goto FINISH;	// [read_png_file] png_create_info_struct failed
 
-  if(setjmp(png_jmpbuf(png_ptr))) goto FINISH;	// [read_png_file] Error during init_io
-
-  png_init_io(png_ptr, f);
-  png_set_sig_bytes(png_ptr, 8);
+  if(!setjmp(png_jmpbuf(png_ptr)))  // if(setjmp ..)goto FINISH;	// [read_png_file] Error during init_io
+  {
+    png_init_io(png_ptr, F);
 
 #if defined(PNG_UNKNOWN_CHUNKS_SUPPORTED)
-  //png_set_keep_unknown_chunks(png_ptr, 2, (png_bytep)mng_eXIf, 1);
-  png_set_read_user_chunk_fn(png_ptr, &Img, read_user_chunk_callback);
+    //png_set_keep_unknown_chunks(png_ptr, 2, (png_bytep)mng_eXIf, 1);
+    png_set_read_user_chunk_fn(png_ptr, Img, read_user_chunk_callback);
 #endif
 
-  png_read_info(png_ptr, info_ptr);
+    png_read_info(png_ptr, info_ptr);
 
-  //color_type = info_ptr->color_type;
-  color_type = png_get_color_type(png_ptr,info_ptr);
+    //color_type = info_ptr->color_type;
+    png_byte color_type = png_get_color_type(png_ptr,info_ptr);
 
-  number_of_passes = png_set_interlace_handling(png_ptr);
-  png_read_update_info(png_ptr, info_ptr);
+    int number_of_passes = png_set_interlace_handling(png_ptr);
+    png_read_update_info(png_ptr, info_ptr);
 
 	/* read file */
-  if(setjmp(png_jmpbuf(png_ptr))) goto FINISH;	  // [read_png_file] Error during read_image  
+    if(setjmp(png_jmpbuf(png_ptr))) goto FINISH;	  // [read_png_file] Error during read_image
 
-  switch(png_get_channels(png_ptr,info_ptr))
+    switch(png_get_channels(png_ptr,info_ptr))
     {
-    case 1: if(png_get_rowbytes(png_ptr,info_ptr) > (png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr)+7)/8) goto FINISH;
+      case 1: if(png_get_rowbytes(png_ptr,info_ptr) > (png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr)+7)/8) goto FINISH;
 	    Raster = CreateRaster2D(png_get_image_width(png_ptr,info_ptr),png_get_image_height(png_ptr,info_ptr),png_get_bit_depth(png_ptr,info_ptr));
 
             png_get_PLTE(png_ptr,info_ptr, &palette, &num_palette);
@@ -150,36 +113,56 @@ int i;
                 {
                 for(i=0;i<num_palette;i++)
 		  {
-		  Palette->R(i,palette[i].red);
-		  Palette->G(i,palette[i].green);
-		  Palette->B(i,palette[i].blue);
+		  Palette->setR(i,palette[i].red);
+		  Palette->setG(i,palette[i].green);
+		  Palette->setB(i,palette[i].blue);
                   }
 		}
               }
 	    break;
-    case 3: if(png_get_rowbytes(png_ptr,info_ptr) > (3*png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr))/8) goto FINISH;
+      case 3: if(png_get_rowbytes(png_ptr,info_ptr) > (3*png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr))/8) goto FINISH;
 	    Raster = CreateRaster2DRGB(png_get_image_width(png_ptr,info_ptr),png_get_image_height(png_ptr,info_ptr),png_get_bit_depth(png_ptr,info_ptr));
 	    break;
-    case 4: if(png_get_rowbytes(png_ptr,info_ptr) > (4*png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr))/8) goto FINISH;
+      case 4: if(png_get_rowbytes(png_ptr,info_ptr) > (4*png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr))/8) goto FINISH;
 	    Raster = CreateRaster2DRGBA(png_get_image_width(png_ptr,info_ptr),png_get_image_height(png_ptr,info_ptr),png_get_bit_depth(png_ptr,info_ptr));
 	    break;
     }
-  if(Raster==NULL) goto FINISH;
+    if(Raster==NULL) goto FINISH;
 
-  png_read_image(png_ptr, (png_byte **)Raster->Data2D);
+    png_read_image(png_ptr, (png_byte **)Raster->Data2D);
 
-  png_read_end(png_ptr, info_ptr);
+    png_read_end(png_ptr, info_ptr);
+  }
+FINISH:
+	/* Clean up after the read, and free any memory allocated - REQUIRED */
+  if(png_ptr)
+      png_destroy_read_struct(&png_ptr, &info_ptr, png_infopp_NULL);
+
+  Img->AttachRaster(Raster);
+  Img->AttachPalette(Palette);
+}
+
+
+Image LoadPicturePNG(const char *Name)
+{
+Image Img;
+FILE *f;
+
+  if((f=fopen(Name,"rb"))==NULL) return(Img);
+
+  {
+    png_byte header[8];			// 8 is the maximum size that can be checked
+    fread(header, 1, 8, f);
+    if(png_sig_cmp(header, 0, 8)) goto FINISH;
+    fseek(f,-8,SEEK_CUR);		// return back to a signature.
+  }
+
+  LoadFragmentPNG(f,&Img);
 
 FINISH:
   fclose(f);
-	/* Clean up after the read, and free any memory allocated - REQUIRED */
-  if(png_ptr)
-    png_destroy_read_struct(&png_ptr, &info_ptr, png_infopp_NULL);
 
-  Img.AttachRaster(Raster);
-  Img.AttachPalette(Palette);  
-
-  return(Img);  /* And we're done! */
+  return(Img);		/* And we're done! */
 }
 #endif
 
@@ -245,13 +228,24 @@ png_colorp palette = NULL;
   switch(Ityp)
   {
     case ImageTrueColor:
-              png_set_IHDR(png_ptr, info_ptr, Img.Raster->Size1D, Img.Raster->Size2D,
-		     Img.Raster->GetPlanes()/3, PNG_COLOR_TYPE_RGB, PNG_INTERLACE_NONE,
-		     PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
+              switch(Img.Raster->Channels())
+              {
+                case 3: png_set_IHDR(png_ptr, info_ptr, Img.Raster->Size1D, Img.Raster->Size2D,
+		                Img.Raster->GetPlanes()/3, PNG_COLOR_TYPE_RGB, PNG_INTERLACE_NONE,
+		                PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
+                                sig_bit.alpha = 0;
+                                sig_bit.blue = sig_bit.green = sig_bit.red = Img.Raster->GetPlanes()/3;
+                        break;
+                case 4: png_set_IHDR(png_ptr, info_ptr, Img.Raster->Size1D, Img.Raster->Size2D,
+		                Img.Raster->GetPlanes()/4, PNG_COLOR_TYPE_RGB_ALPHA, PNG_INTERLACE_NONE,
+		                PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
+			        sig_bit.blue = sig_bit.green = sig_bit.red = sig_bit.alpha = Img.Raster->GetPlanes()/4;
+                        break;
+                default:fclose(fp);		// Unsupported channel count.
+                        png_destroy_write_struct(&png_ptr, &info_ptr);
+                        return -8;
+              }
 		   /* Otherwise, if we are dealing with a color image then */
-              sig_bit.blue = 
-                  sig_bit.green = 
-	          sig_bit.red = Img.Raster->GetPlanes() / 3;
               png_set_sBIT(png_ptr, info_ptr, &sig_bit);
               break;
     case ImageGray:
@@ -269,6 +263,12 @@ png_colorp palette = NULL;
 		   /* Set the palette if there is one.  REQUIRED for indexed-color images */
 	      palette = (png_colorp)png_malloc(png_ptr, PNG_MAX_PALETTE_LENGTH*png_sizeof(png_color));
 		   /* ... Set palette colors ... */
+              for(int i=0; i<PNG_MAX_PALETTE_LENGTH; i++)
+	      {
+		  palette[i].red = Img.Palette->R(i);
+		  palette[i].green = Img.Palette->G(i);
+		  palette[i].blue = Img.Palette->B(i);
+              }
 	      png_set_PLTE(png_ptr, info_ptr, palette, PNG_MAX_PALETTE_LENGTH);
 		  /* You must not free palette here, because png_set_PLTE only makes a link to
 		   * the palette that you malloced.  Wait until you are about to destroy
@@ -313,7 +313,7 @@ png_colorp palette = NULL;
         WrDWORD_HiEnd(Prop->DataSize,fp);
         fwrite(mng_eXIf,1,4,fp);
         fwrite(Prop->Data,1,Prop->DataSize,fp);
-        const DWORD CRC = crc32(crc32(0,mng_eXIf,4), (const Bytef*)(Prop->Data), (DWORD)Prop->DataSize);
+        const uint32_t CRC = crc32(crc32(0,mng_eXIf,4), (const Bytef*)(Prop->Data), (uint32_t)Prop->DataSize);
         WrDWORD_HiEnd(CRC,fp);
       }
     }
