@@ -1,5 +1,5 @@
 /***************************************************************************
- * Unit:    raster            release 0.24                                 *
+ * Unit:    raster            release 0.25                                 *
  * Purpose: Prototypes for general manipulation n dimensional matrices     *
  * Modul:   raster.cc                                                      *
  * Licency: GPL or LGPL                                                    *
@@ -10,7 +10,7 @@
 
 #include "typedfs.h"
 
-#define RASTER_VERSION (0x100*0 | 24)
+#define RASTER_VERSION (0x100*0 | 25)
 
 #ifndef No_Memory
  #define No_Memory    0x1
@@ -53,54 +53,54 @@ extern "C" {
 #define RGBQuad_DEFINED
 typedef struct
 	{
-	unsigned R,G,B,O;
+	uint32_t R,G,B,O;
 	} RGBQuad;
 #endif
 
-void Conv1_4(BYTE *Dest, const BYTE *Src, unsigned Size1D);
-void Conv1_8(BYTE *Dest, const BYTE *Src, unsigned Size1D);
-void Conv1_16(WORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv1_24(BYTE *Dest, const BYTE *Src, unsigned Size1D);
-void Conv1_32(DWORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv4_1(BYTE *Dest, const BYTE *Src, unsigned Size1D);
-void Conv4_8(BYTE *Dest, const BYTE *Src, unsigned Size1D);
-void Conv4_16(WORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv4_32(DWORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv8_1(BYTE *Dest, const BYTE *Src, unsigned Size1D);
-void Conv8_4(BYTE *Dest, const BYTE *Src, unsigned Size1D);
-void Conv8_16(WORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv8_24(BYTE *Dest, const BYTE *Src, unsigned Size1D);
-void Conv8_32(DWORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv16_1(BYTE *Dest, const WORD *Src, unsigned Size1D);
-void Conv16_4(BYTE *Dest, const WORD *Src, unsigned Size1D);
-void Conv16_8(BYTE *Dest, const WORD *Src, unsigned Size1D);
-void Conv16_24(BYTE *Dest, const WORD *Src, unsigned Size1D);
-void Conv16_32(DWORD *Dest, const WORD *Src, unsigned Size1D);
-void Conv24_8(BYTE *Dest, const BYTE *Src, unsigned Size1D);
-void Conv24_16(WORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv24_32(DWORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv32_1(BYTE *Dest, const DWORD *Src, unsigned Size1D);
-void Conv32_4(BYTE *Dest, const DWORD *Src, unsigned Size1D);
-void Conv32_8(BYTE *Dest, const DWORD *Src, unsigned Size1D);
-void Conv32_16(WORD *Dest, const DWORD *Src, unsigned Size1D);
-void Conv32_24(BYTE *Dest, const DWORD *Src, unsigned Size1D);
+void Conv1_4(uint8_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv1_8(uint8_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv1_16(uint16_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv1_24(uint8_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv1_32(uint32_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv4_1(uint8_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv4_8(uint8_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv4_16(uint16_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv4_32(uint32_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv8_1(uint8_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv8_4(uint8_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv8_16(uint16_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv8_24(uint8_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv8_32(uint32_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv16_1(uint8_t *Dest, const uint16_t *Src, unsigned Size1D);
+void Conv16_4(uint8_t *Dest, const uint16_t *Src, unsigned Size1D);
+void Conv16_8(uint8_t *Dest, const uint16_t *Src, unsigned Size1D);
+void Conv16_24(uint8_t *Dest, const uint16_t *Src, unsigned Size1D);
+void Conv16_32(uint32_t *Dest, const uint16_t *Src, unsigned Size1D);
+void Conv24_8(uint8_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv24_16(uint16_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv24_32(uint32_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv32_1(uint8_t *Dest, const uint32_t *Src, unsigned Size1D);
+void Conv32_4(uint8_t *Dest, const uint32_t *Src, unsigned Size1D);
+void Conv32_8(uint8_t *Dest, const uint32_t *Src, unsigned Size1D);
+void Conv32_16(uint16_t *Dest, const uint32_t *Src, unsigned Size1D);
+void Conv32_24(uint8_t *Dest, const uint32_t *Src, unsigned Size1D);
 
-#ifdef QWORD
-void Conv1_64(QWORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv8_64(QWORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv24_64(QWORD *Dest, const BYTE *Src, unsigned Size1D);
-void Conv32_64(QWORD *Dest, const DWORD *Src, unsigned Size1D);
+#if defined(uint64_t) || defined(uint64_t_defined)
+void Conv1_64(uint64_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv8_64(uint64_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv24_64(uint64_t *Dest, const uint8_t *Src, unsigned Size1D);
+void Conv32_64(uint64_t *Dest, const uint32_t *Src, unsigned Size1D);
 #endif
 
 
-void Flip1(BYTE *b, unsigned len);
-void Flip4(BYTE *b, unsigned len);
-void Flip8(BYTE *b, unsigned len);
-void Flip16(WORD *w, unsigned len);
-void Flip24(BYTE *b, unsigned len);
-void Flip32(DWORD *d, unsigned len);
-#ifdef QWORD
-void Flip64(QWORD *d, unsigned len);
+void Flip1(uint8_t *b, unsigned len);
+void Flip4(uint8_t *b, unsigned len);
+void Flip8(uint8_t *b, unsigned len);
+void Flip16(uint16_t *w, unsigned len);
+void Flip24(uint8_t *b, unsigned len);
+void Flip32(uint32_t *d, unsigned len);
+#if defined(uint64_t) || defined(uint64_t_defined)
+void Flip64(uint64_t *d, unsigned len);
 #endif
 
 #ifdef __cplusplus
@@ -147,10 +147,10 @@ public: mutable short UsageCount;
 	virtual void Cleanup(void);
 	void Erase1DStub(void);
 
-	virtual DWORD GetValue1D(unsigned x) const {return(0);};
+	virtual uint32_t GetValue1D(unsigned x) const {return(0);};
 	virtual double GetValue1Dd(unsigned x) const {return(GetValue1D(x));};
-	virtual void SetValue1D(unsigned x, DWORD NewValue) ABSTRACT_ERROR("SetValue1D");
-	virtual void SetValue1Dd(unsigned x, double NewValue) {SetValue1D(x,(DWORD)NewValue);};
+	virtual void SetValue1D(unsigned x, uint32_t NewValue) ABSTRACT_ERROR("SetValue1D");
+	virtual void SetValue1Dd(unsigned x, double NewValue) {SetValue1D(x,(uint32_t)NewValue);};
 	virtual void Get(unsigned x, RGBQuad *RGB) const {RGB->R=RGB->G=RGB->B=GetValue1D(x);};
 
 	virtual int GetPlanes(void) const {return(0);};
@@ -168,8 +168,8 @@ public: mutable short UsageCount;
 /* Bitwise operation with raster buffer. */
 	virtual void Peel1Bit(void *Buffer1Bit, char plane) const;
 	virtual void Join1Bit(void *Buffer1Bit, char plane);
-	virtual void Peel8Bit(BYTE *Buffer8Bit, char plane8) const;
-	virtual void Join8Bit(BYTE *Buffer8Bit, char plane8);
+	virtual void Peel8Bit(uint8_t *Buffer8Bit, char plane8) const;
+	virtual void Join8Bit(uint8_t *Buffer8Bit, char plane8);
 
 	virtual Raster1DAbstract *GetPalette(void) {return(NULL);}
 	virtual void SetPalette(Raster1DAbstract *NewPalette) {AbstractError("Raster1DAbstract::SetPalette");}
@@ -177,10 +177,10 @@ public: mutable short UsageCount;
 
 protected:
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const {return(0);};
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const {return(0);};
 	virtual double PTR_GetValue1Dd(const void *RAW_Data1D, unsigned x) const {return(PTR_GetValue1D(RAW_Data1D,x));};
-	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const = 0; // {AbstractError("RAW_SetValue1D");};
-	virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) {PTR_SetValue1D(RAW_Data1D,x,(DWORD)NewValue);};
+	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const = 0; // {AbstractError("RAW_SetValue1D");};
+	virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) {PTR_SetValue1D(RAW_Data1D,x,(uint32_t)NewValue);};
         virtual void PTR_Get(const void *RAW_Data1D, Raster1DAbstract &R1) const;
         virtual void PTR_Set(void *RAW_Data1D, const Raster1DAbstract &R1);
 #endif
@@ -191,8 +191,8 @@ Raster1DAbstract *CreateRaster1D(unsigned Size1D, int Planes);
 class Raster1DAbstractRGB: virtual public Raster1DAbstract
 {
 public:
-  virtual DWORD GetValue1DRAW(unsigned x) const ABSTRACT_ERRORi("Raster1DAbstractRGB::GetValue1DRAW");
-  virtual void SetValue1DRAW(unsigned x, DWORD NewValue) ABSTRACT_ERROR("Raster1DAbstractRGB::SetValue1DRAW");
+  virtual uint32_t GetValue1DRAW(unsigned x) const ABSTRACT_ERRORi("Raster1DAbstractRGB::GetValue1DRAW");
+  virtual void SetValue1DRAW(unsigned x, uint32_t NewValue) ABSTRACT_ERROR("Raster1DAbstractRGB::SetValue1DRAW");
 
   virtual unsigned GetSize1D(void) const {return(Size1D);};
   virtual char Channels(void) const {return 3;};
@@ -203,30 +203,31 @@ public:
   virtual void Get(unsigned index, RGBQuad *RGB) const;
   virtual void Set(unsigned index, const RGBQuad *RGB);
 
-  unsigned R(unsigned x) const {return(GetValue1DRAW(3*x));}
-  unsigned G(unsigned x) const {return(GetValue1DRAW(3*x+1));}
-  unsigned B(unsigned x) const {return(GetValue1DRAW(3*x+2));}
+  uint32_t R(unsigned x) const {return(GetValue1DRAW(3*x));}
+  uint32_t G(unsigned x) const {return(GetValue1DRAW(3*x+1));}
+  uint32_t B(unsigned x) const {return(GetValue1DRAW(3*x+2));}
 
-  void R(unsigned x, unsigned newR) {SetValue1DRAW(3*x,newR);};
-  void G(unsigned x, unsigned newG) {SetValue1DRAW(3*x+1,newG);};
-  void B(unsigned x, unsigned newB) {SetValue1DRAW(3*x+2,newB);};
+  void setR(unsigned x, uint32_t newR) {SetValue1DRAW(3*x,newR);};
+  void setG(unsigned x, uint32_t newG) {SetValue1DRAW(3*x+1,newG);};
+  void setB(unsigned x, uint32_t newB) {SetValue1DRAW(3*x+2,newB);};
+  void setA(unsigned x, uint32_t newA) {};
 
   friend Raster1DAbstractRGB *CreateRaster1DRGB(unsigned SizeX, unsigned Planes);
 
 #ifdef _REENTRANT
 protected:
-  virtual DWORD PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const = 0; // {AbstractError("PTR_GetValue1DRAW");return 0;};
-  virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, DWORD NewValue) = 0; // {AbstractError("PTR_SetValue1DRAW");};
+  virtual uint32_t PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const = 0; // {AbstractError("PTR_GetValue1DRAW");return 0;};
+  virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, uint32_t NewValue) = 0; // {AbstractError("PTR_SetValue1DRAW");};
 #endif
 };
 Raster1DAbstractRGB *CreateRaster1DRGB(unsigned Size1D, int Planes);
 
 
-class Raster1DAbstractRGBA: virtual public Raster1DAbstract
+class Raster1DAbstractRGBA: virtual public Raster1DAbstractRGB
 {
 public:
-  virtual DWORD GetValue1DRAW(unsigned x) const ABSTRACT_ERRORi("Raster1DAbstractRGBA::GetValue1DRAW");
-  virtual void SetValue1DRAW(unsigned x, DWORD NewValue) ABSTRACT_ERROR("Raster1DAbstractRGBA::SetValue1DRAW");
+  virtual uint32_t GetValue1DRAW(unsigned x) const ABSTRACT_ERRORi("Raster1DAbstractRGBA::GetValue1DRAW");
+  virtual void SetValue1DRAW(unsigned x, uint32_t NewValue) ABSTRACT_ERROR("Raster1DAbstractRGBA::SetValue1DRAW");
 
   virtual unsigned GetSize1D(void) const {return(Size1D);};
   virtual char Channels(void) const {return 4;};
@@ -236,22 +237,22 @@ public:
   virtual void Get(unsigned index, RGBQuad *RGB) const;
   virtual void Set(unsigned index, const RGBQuad *RGB);
 
-  unsigned R(unsigned x) const {return(GetValue1DRAW(4*x));}
-  unsigned G(unsigned x) const {return(GetValue1DRAW(4*x+1));}
-  unsigned B(unsigned x) const {return(GetValue1DRAW(4*x+2));}
-  unsigned A(unsigned x) const {return(GetValue1DRAW(4*x+3));}
+  uint32_t R(unsigned x) const {return(GetValue1DRAW(4*x));}
+  uint32_t G(unsigned x) const {return(GetValue1DRAW(4*x+1));}
+  uint32_t B(unsigned x) const {return(GetValue1DRAW(4*x+2));}
+  uint32_t A(unsigned x) const {return(GetValue1DRAW(4*x+3));}
 
-  void R(unsigned x, unsigned newR) {SetValue1DRAW(4*x  ,newR);};
-  void G(unsigned x, unsigned newG) {SetValue1DRAW(4*x+1,newG);};
-  void B(unsigned x, unsigned newB) {SetValue1DRAW(4*x+2,newB);};
-  void A(unsigned x, unsigned newA) {SetValue1DRAW(4*x+3,newA);};
+  void setR(unsigned x, uint32_t newR) {SetValue1DRAW(4*x  ,newR);};
+  void setG(unsigned x, uint32_t newG) {SetValue1DRAW(4*x+1,newG);};
+  void setB(unsigned x, uint32_t newB) {SetValue1DRAW(4*x+2,newB);};
+  void setA(unsigned x, uint32_t newA) {SetValue1DRAW(4*x+3,newA);};
 
   friend Raster1DAbstractRGBA *CreateRaster1DRGBA(unsigned Size1D, int Planes);
 
 #ifdef _REENTRANT
 protected:
-  virtual DWORD PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const = 0; // {AbstractError("PTR_GetValue1DRAW");return 0;};
-  virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, DWORD NewValue) = 0; // {AbstractError("PTR_SetValue1DRAW");};
+  virtual uint32_t PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const = 0; // {AbstractError("PTR_GetValue1DRAW");return 0;};
+  virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, uint32_t NewValue) = 0; // {AbstractError("PTR_SetValue1DRAW");};
 #endif
 };
 
@@ -272,13 +273,14 @@ public: unsigned Size2D;
 	virtual void Cleanup(void);
         unsigned GetSize2D(void) const {return(Size2D);};
 
-	DWORD GetValue2D(unsigned Offset1D, unsigned Offset2D) MP_CONST;
+	uint32_t GetValue2D(unsigned Offset1D, unsigned Offset2D) MP_CONST;
 	double GetValue2Dd(unsigned Offset1D, unsigned Offset2D) MP_CONST;
 	void SetValue2D(unsigned Offset1D, unsigned Offset2D, long x);
 	void SetValue2Dd(unsigned Offset1D, unsigned Offset2D, double x);
 
 	void *GetRow(unsigned Offset2D)   {if(Data2D==NULL || Offset2D>=Size2D) return(NULL);return(Data2D[Offset2D]);}
         const void *GetRow(unsigned Offset2D) const {if(Data2D==NULL || Offset2D>=Size2D) return(NULL);return(Data2D[Offset2D]);}
+        virtual void Get(unsigned Offset1D, unsigned Offset2D, RGBQuad *RGB);
 
 	Raster1DAbstract *GetRowRaster(unsigned Offset2D);
 
@@ -293,9 +295,9 @@ protected:
 	void Erase2DStub(void);
 
 #if defined(_REENTRANT) && defined(RASTER_3D)
-        DWORD PTR_GetValue2D(const void **RAW_Data2D, unsigned Offset1D, unsigned Offset2D) const;
+        uint32_t PTR_GetValue2D(const void **RAW_Data2D, unsigned Offset1D, unsigned Offset2D) const;
 	double PTR_GetValue2Dd(const void **RAW_Data2D, unsigned Offset1D, unsigned Offset2D) const;
-	void PTR_SetValue2D(void **RAW_Data2D, unsigned Offset1D, unsigned Offset2D, DWORD NewValue) const;
+	void PTR_SetValue2D(void **RAW_Data2D, unsigned Offset1D, unsigned Offset2D, uint32_t NewValue) const;
 	void PTR_SetValue2Dd(void **RAW_Data2D, unsigned Offset1D, unsigned Offset2D, double NewValue) const;
         void PTR_Get(const void **RAW_Data2D, unsigned Offset2D, Raster1DAbstract &R1) const;
         void PTR_Set(void **RAW_Data2D, unsigned Offset2D, const Raster1DAbstract &R1);
@@ -309,16 +311,18 @@ Raster2DAbstract *CreateRaster2D(unsigned Size1D, unsigned Size2D, int Planes);
 class Raster2DAbstractRGB: virtual public Raster2DAbstract, virtual public Raster1DAbstractRGB
 {
 public:
-	virtual DWORD GetValue2DRAW(unsigned Offset1D, unsigned Offset2D);
-	virtual void SetValue2DRAW(unsigned Offset1D, unsigned Offset2D, DWORD x);
+	virtual uint32_t GetValue2DRAW(unsigned Offset1D, unsigned Offset2D);
+	virtual void SetValue2DRAW(unsigned Offset1D, unsigned Offset2D, uint32_t x);
 
-	unsigned R(unsigned x, unsigned y) {return(GetValue2DRAW(3*x,y));}
-	unsigned G(unsigned x, unsigned y) {return(GetValue2DRAW(3*x+1,y));}
-	unsigned B(unsigned x, unsigned y) {return(GetValue2DRAW(3*x+2,y));}
+	uint32_t R(unsigned x, unsigned y) {return(GetValue2DRAW(3*x,y));}
+	uint32_t G(unsigned x, unsigned y) {return(GetValue2DRAW(3*x+1,y));}
+	uint32_t B(unsigned x, unsigned y) {return(GetValue2DRAW(3*x+2,y));}
 
-	void R(unsigned x, unsigned y, unsigned newR) {SetValue2DRAW(3*x,y,newR);};
-	void G(unsigned x, unsigned y, unsigned newG) {SetValue2DRAW(3*x+1,y,newG);};
-	void B(unsigned x, unsigned y, unsigned newB) {SetValue2DRAW(3*x+2,y,newB);};
+	void setR(unsigned x, unsigned y, uint32_t newR) {SetValue2DRAW(3*x,y,newR);};
+	void setG(unsigned x, unsigned y, uint32_t newG) {SetValue2DRAW(3*x+1,y,newG);};
+	void setB(unsigned x, unsigned y, uint32_t newB) {SetValue2DRAW(3*x+2,y,newB);};
+
+	Raster1DAbstractRGB *GetRowRasterRGB(unsigned Offset2D);
 
 	friend Raster2DAbstractRGB *CreateRaster2DRGB(unsigned SizeX, unsigned SizeY, int Planes);
 };
@@ -326,21 +330,23 @@ public:
 Raster2DAbstractRGB *CreateRaster2DRGB(unsigned Size1D, unsigned Size2D, int Planes);
 
 
-class Raster2DAbstractRGBA: virtual public Raster2DAbstract, virtual public Raster1DAbstractRGBA
+class Raster2DAbstractRGBA: virtual public Raster2DAbstractRGB, virtual public Raster1DAbstractRGBA
 {
 public:
-	virtual DWORD GetValue2DRAW(unsigned Offset1D, unsigned Offset2D);
-	virtual void SetValue2DRAW(unsigned Offset1D, unsigned Offset2D, DWORD x);
+	virtual uint32_t GetValue2DRAW(unsigned Offset1D, unsigned Offset2D);
+	virtual void SetValue2DRAW(unsigned Offset1D, unsigned Offset2D, uint32_t x);
 
-	unsigned R(unsigned x, unsigned y) {return(GetValue2DRAW(4*x,y));}
-	unsigned G(unsigned x, unsigned y) {return(GetValue2DRAW(4*x+1,y));}
-	unsigned B(unsigned x, unsigned y) {return(GetValue2DRAW(4*x+2,y));}
-	unsigned A(unsigned x, unsigned y) {return(GetValue2DRAW(4*x+3,y));}
+	uint32_t R(unsigned x, unsigned y) {return(GetValue2DRAW(4*x,y));}
+	uint32_t G(unsigned x, unsigned y) {return(GetValue2DRAW(4*x+1,y));}
+	uint32_t B(unsigned x, unsigned y) {return(GetValue2DRAW(4*x+2,y));}
+	uint32_t A(unsigned x, unsigned y) {return(GetValue2DRAW(4*x+3,y));}
 
-	void R(unsigned x, unsigned y, unsigned newR) {SetValue2DRAW(4*x,y,newR);};
-	void G(unsigned x, unsigned y, unsigned newG) {SetValue2DRAW(4*x+1,y,newG);};
-	void B(unsigned x, unsigned y, unsigned newB) {SetValue2DRAW(4*x+2,y,newB);};
-	void A(unsigned x, unsigned y, unsigned newA) {SetValue2DRAW(4*x+3,y,newA);};
+	void setR(unsigned x, unsigned y, uint32_t newR) {SetValue2DRAW(4*x,y,newR);};
+	void setG(unsigned x, unsigned y, uint32_t newG) {SetValue2DRAW(4*x+1,y,newG);};
+	void setB(unsigned x, unsigned y, uint32_t newB) {SetValue2DRAW(4*x+2,y,newB);};
+	void setA(unsigned x, unsigned y, uint32_t newA) {SetValue2DRAW(4*x+3,y,newA);};
+
+	//virtual void A(unsigned x, uint32_t newA) {Raster1DAbstractRGBA::A(x,newA);};
 
 	friend Raster2DAbstractRGBA *CreateRaster2DRGBA(unsigned SizeX, unsigned SizeY, int Planes);
 };
@@ -374,9 +380,9 @@ public: unsigned Size3D;
         virtual void Cleanup(void);
         unsigned GetSize3D(void) const {return(Size3D);};
 
-	DWORD GetValue3D(unsigned Offset1D, unsigned Offset2D, unsigned Offset3D) MP_CONST;
+	uint32_t GetValue3D(unsigned Offset1D, unsigned Offset2D, unsigned Offset3D) MP_CONST;
         double GetValue3Dd(unsigned Offset1D, unsigned Offset2D, unsigned Offset3D) MP_CONST;
-	void SetValue3D(unsigned Offset1D, unsigned Offset2D, unsigned Offset3D, DWORD x);
+	void SetValue3D(unsigned Offset1D, unsigned Offset2D, unsigned Offset3D, uint32_t x);
         void SetValue3Dd(unsigned Offset1D, unsigned Offset2D, unsigned Offset3D, double x);
 
 	void **GetRow(unsigned Offset3D)   {if(Data3D==NULL || Offset3D>=Size3D) return(NULL);return(Data3D[Offset3D]);}
@@ -402,39 +408,6 @@ void Flip2D(Raster3DAbstract *r3D);
 void Flip3D(Raster3DAbstract *r3D);
 #endif
 
-/* ---------- Global class Image --------- */
-#include "stringa.h"
-
-
-#define RAS_IMG_VERSION (0x200 | 61)
-
-/*Definition of errors while Loading/Saving File(s)*/
-#define ErrOK		  0
-#define ErrOpenFile	 -1
-#define ErrReadFile	 -2
-#define ErrWriteFile	 -3
-#define ErrBadFileFormat -4
-
-#define ErrNoMem	-10
-
-
-
-#ifndef RGBQuad_DEFINED
-#define RGBQuad_DEFINED
-typedef struct
-	{
-	unsigned R,G,B,O;
-	} RGBQuad;
-#endif
-
-
-struct RGB_Record
-   {
-   BYTE Red;
-   BYTE Green;
-   BYTE Blue;
-   };
-
 
 
 class APalette: virtual public Raster1DAbstractRGB
@@ -470,122 +443,36 @@ typedef enum
   EPS_FillPlus	  = 128,
   EPS_FillBalls	  = 256,
   EPS_FillTriangle= 512,
-  EPS_FillSmSquare=1024
+  EPS_FillSmSquare=1024,
+  EPS_FillBricks   =2048,
+  EPS_FillDiagBricks=4096,
+  EPS_FillHoneycomb=8192,
+  EPS_FillFishscale=16384,
+#if !defined(__BORLANDC__) || (__BORLANDC__>=0x0500)
+  EPS_FillArch   =  32768,
+  EPS_FillChainlink=65536,
+  EPS_FillPatio=  0x20000,
+  EPS_FillWeave=  0x40000,
+  EPS_FillWaves = 0x80000
+#else
+  #define EPS_FillArch 32768
+  #define EPS_FillChainlink 65536
+  #define EPS_FillPatio 0x20000
+  #define EPS_FillWeave 0x40000
+  #define EPS_FillWaves 0x80000
+#endif
 } EPS_COMPONENTS;
 
 
-class VectorImage;
-
-
-class PropertyItem
-{
-public:
-  PropertyItem(void) {Data=NULL;DataSize=0;UsageCount=0;}
-  virtual ~PropertyItem();
-
-  mutable short UsageCount;
-  void *Data;
-  unsigned DataSize;
-  string Name;
-};
-
-
-class PropertyList
-{
-public:
-  PropertyList(void) {pProperties=NULL;PropCount=0;};
-  ~PropertyList();
-
-  void AddProp(PropertyItem *NewProp);
-  bool isEmpty(void) const {return PropCount==0 || pProperties==NULL;}
-
-  int PropCount;
-  PropertyItem **pProperties;
-};
-
-
-class Image
-	{
-public: Raster2DAbstract *Raster;
-	APalette *Palette;
-	Image *Next;
-	float x,y,dx,dy,RotAngle;
-	VectorImage *VecImage;
-	PropertyList Properties;
-
-	Image(void): VecImage(NULL)  {RotAngle=x=y=dx=dy=0;Raster=NULL;Next=NULL;Palette=NULL;};
-	Image(const Image & I, bool AllFrames=true);
-	Image(Raster2DAbstract *NewRaster): VecImage(NULL) {RotAngle=x=y=dx=dy=0;Next=NULL;Palette=NULL;if((Raster=NewRaster)!=NULL) Raster->UsageCount++;};
-	~Image(void) {Erase();};
-	IMAGE_TYPE ImageType(void) const;   // 0-none, 1-gray, 2-palette, 3-true color
-
-	Raster2DAbstract *operator=(Raster2DAbstract *NewRaster);
-	Image &operator=(const Image & I);
-
-	DWORD GetPixel(unsigned Offset1D, unsigned Offset2D) const {return(Raster==NULL?0:Raster->GetValue2D(Offset1D,Offset2D));};
-	DWORD GetPixelRGB(unsigned Offset1D, unsigned Offset2D) const;
-	
-	void SetPixel(unsigned SizeX, unsigned SizeY, DWORD x) {if(Raster) Raster->SetValue2D(SizeX,SizeY,x);};
-
-	void Create(unsigned SizeX, unsigned SizeY, int Planes);
-	void Erase(void);
-	void AttachRaster(Raster2DAbstract *NewRaster);
-	void AttachPalette(APalette *NewPalette);
-	void AttachVecImg(VectorImage *NewVecImg);
-	void AttachProperty(PropertyItem *NewProp);
-	};
-
 
 void Flip1D(Raster1DAbstract *r1D);
 
 void Flip1D(Raster2DAbstract *r2D);
 void Flip2D(Raster2DAbstract *r2D);
-int ReducePalette(Image *Img, unsigned maxColors);
 int GrayPalette(APalette *Palette, int Planes=0);
 int FillGray(Raster1DAbstractRGB *Palette, int Planes=0);
 
 
-typedef struct
-{
-  float MinX;
-  float MaxX;
-  float MinY;
-  float MaxY;
-} FloatBBox;
-
-void InitBBox(FloatBBox & bbx);
-
-void UpdateBBox(FloatBBox & bbx,
-		float alpha, float x, float y, float dx, float dy);
-
-
-/* -----File format loader dynamical list------ */
-typedef Image (* TLoadPicture)(const char *Name);
-typedef int (*TSavePicture)(const char *Name, const Image &Img);
-
-class TImageFileHandler
-	{
-private:static TImageFileHandler *First;
-	TImageFileHandler *Previous;
-	TImageFileHandler *Next;
-
-	const char *Extension;
-        const char *Description;
-
-public: TImageFileHandler(const char *NewShortKey, TLoadPicture LoadPicture_XXX = NULL, TSavePicture SavePicture_XXX=NULL, const char *NewDescription=NULL);
-	~TImageFileHandler();
-
-	TLoadPicture LoadPicture;
-	TSavePicture SavePicture;
-	const char *extension() {return(Extension);}
-	const char *description() {return(Description);}
-
-	static TImageFileHandler *first() {return(First);}
-	TImageFileHandler *next() {return(Next);}
-	};
-
-int SavePicture(const char *Name,const Image &Img);
-Image LoadPicture(const char *Name);
 
 #endif // C++
 
