@@ -9,15 +9,22 @@
 #include <stdio.h>
 #include <math.h>
 
+#include "matrix.h"
+
 #include "vecimage.h"
 
 
+#ifndef M_PI
+ #define M_PI        3.14159265358979323846
+#endif
+
+
 static void FixPsAccent(string & s, const char *TexAccent, const char *PsAccent);
 static void FixPsAccent2(string & s, const char *TexAccent, const char *PsAccent);
 
 
 /** Normalise angle after difference calculatiun to be in a range <-pi;+pi>
- * @param[in]	num1	Angle to normalise.
+ * @param[in]	num1	Angle to normalise [deg].
  * @return		Normalised angle. */
 float NormAngleDEG(float num1)
 {  
@@ -37,6 +44,112 @@ return num1;
 }
 
 
+void UpdateBBox(FloatBBox & bbx, const float_matrix & corners)
+{
+   for(int i=0;i<corners.cols();i++)
+   {
+     const float x = corners(i,0);
+     const float y = corners(i,1);
+     if(bbx.MinX>x) bbx.MinX=x;
+     if(bbx.MaxX<x) bbx.MaxX=x;
+     if(bbx.MinY>y) bbx.MinY=y;
+     if(bbx.MaxY<y) bbx.MaxY=y;
+      //printf("[%.1f,%.1f]", x, y);
+   }
+}
+
+
+void InitBBox(FloatBBox & bbx)
+{
+  bbx.MinY = bbx.MinX = 65537; 
+  bbx.MaxY = bbx.MaxX =-32767;
+}
+
+
+void UpdateBBox(FloatBBox & bbx, const AbstractTransformXY *Tr, const FloatBBox & bbxIn)
+{
+  float x, y;
+  x=bbxIn.MinX;		y=bbxIn.MinY;
+  if(Tr) Tr->ApplyTransform(x,y);
+  UpdateBBox(bbx, 0, x,y, 0,0);
+  x=bbxIn.MaxX;		y=bbxIn.MaxY;
+  if(Tr) Tr->ApplyTransform(x,y);
+  UpdateBBox(bbx, 0, x,y, 0,0);
+  if(Tr)	// second diagonal makes sense only when shape is transformed.
+  {
+    x=bbxIn.MinX;		y=bbxIn.MaxY;
+    Tr->ApplyTransform(x,y);
+    UpdateBBox(bbx, 0, x,y, 0,0);
+    x=bbxIn.MaxX;		y=bbxIn.MinY;
+    Tr->ApplyTransform(x,y);
+    UpdateBBox(bbx, 0, x,y, 0,0);
+  }
+}
+
+
+/// @param[in,out]	bbx	Bounding box structure.
+/// @param[in]		alpha	Rotation angle [deg].
+/// @param[in]		x	Low left corner x coordinate.
+/// @param[in]		y	Low left corner y coordinate.
+/// @param[in]		dx	Width.
+/// @param[in]		dy	Height.
+void UpdateBBox(FloatBBox & bbx,
+		float alpha, float x, float y, float dx, float dy)
+{
+  if(dx<0)
+      {
+      x += dx;
+      dx = -dx;
+      }
+  if(dy<0)
+      {
+      y += dy;
+      dy = -dy;
+      }
+
+  if(fabs(alpha)<1e-6)
+      {
+      if(bbx.MinX>x)    bbx.MinX = x;
+      if(bbx.MinY>y)    bbx.MinY = y;
+      if(bbx.MaxX<x+dx) bbx.MaxX = x+dx;
+      if(bbx.MaxY<y+dy) bbx.MaxY = y+dy;
+      return;
+      }
+  else
+  {
+    float_matrix m(3,3);
+
+//     |1  0 -Sx|   |cos -sin 0|   |1  0 Sx|
+// R = |0  1 -Sy| * |sin  cos 0| * |0  1 Sy|
+//     |0  0   1|   |0     0  1|   |0  0  1|
+    alpha = ((float)M_PI*alpha)/180.0f;	//calculate radians    
+      {
+      const float X0 = x+dx/2;
+      const float Y0 = y+dy/2;
+      const float CosAlpha = cos(alpha);
+      const float SinAlpha = sin(alpha);
+      m(0,0) = CosAlpha;
+      m(1,0) =-SinAlpha;
+      m(2,0) =-X0*CosAlpha + Y0*SinAlpha + X0;
+      m(0,1) = SinAlpha;
+      m(1,1) = CosAlpha;
+      m(2,1) =-X0*SinAlpha - Y0*CosAlpha + Y0;	// Y0*(1-cos(alpha))-X0*sin(alpha);
+      m(0,2)=0;  m(1,2)=0;  m(2,2)=1;
+      }
+    
+    float_matrix corners(4,3,1.0);
+    corners(0,0)=x;	corners(0,1)=y;
+    corners(1,0)=x+dx;	corners(1,1)=y;
+    corners(2,0)=x+dx;	corners(2,1)=y+dy;
+    corners(3,0)=x;	corners(3,1)=y+dy;
+
+    corners = m*corners;
+    //printf("\nalpha=%f ",alpha);
+    UpdateBBox(bbx, corners);
+  }
+}
+
+
 /// Emit Postscript command for font selection.
 /// @param[in,out]	Text	String builter that holds whole PS image.
 /// @param[in]		FontSize  Size of font in [points]
@@ -79,6 +192,18 @@ PS_State::PS_State(void)
 }
 
 
+PS_State::PS_State(const PS_State &PSS)
+{
+  memcpy((PS_StateC *)this, (PS_StateC *)&PSS, sizeof(PS_StateC));
+  FontName = PSS.FontName;
+  PaperBackground = PSS.PaperBackground;
+  pPalette = PSS.pPalette;
+  if(pPalette!=NULL) pPalette->UsageCount++;
+  pRaster = PSS.pRaster;
+  if(pRaster!=NULL) pRaster->UsageCount++;
+}
+
+
 PS_State::~PS_State()
 {
   if(pPalette != NULL)
@@ -133,7 +258,6 @@ void PS_State::AttachRaster(Raster2DAbstract *NewRaster)
 }
 
 
-
 ////////////////////////////////////
 
 vecPen::vecPen(void)
@@ -223,7 +347,7 @@ void vecBrush::AttribFromPSS(const PS_State &PSS)
 }
 
 
-void vecBrush::FeaturesEPS(unsigned & Feature) const 
+void vecBrush::FeaturesEPS(uint32_t & Feature) const 
 {
   switch(BrushStyle & 0x7F)
   {
@@ -233,6 +357,15 @@ void vecBrush::FeaturesEPS(unsigned & Feature) const
     case FILL_BALLS:	Feature|=EPS_FillBalls; break;
     case FILL_TRIANGLES:Feature|=EPS_FillTriangle; break;
     case FILL_SM_SQUARES:Feature|=EPS_FillSmSquare; break;
+    case FILL_BRICKS:   Feature|=EPS_FillBricks; break;
+    case FILL_DIAG_BRICKS:Feature|=EPS_FillDiagBricks; break;
+    case FILL_HONEYCOMB:Feature|=EPS_FillHoneycomb; break;
+    case FILL_FISHSCALE:Feature|=EPS_FillFishscale; break;
+    case FILL_ARCH:	Feature|=EPS_FillArch; break;
+    case FILL_CHAINLINK:Feature|=EPS_FillChainlink; break;
+    case FILL_PATIO:	Feature|=EPS_FillPatio; break;
+    case FILL_WEAVE:	Feature|=EPS_FillWeave; break;
+    case FILL_WAVES:	Feature|=EPS_FillWaves; break;
   }
 }
 
@@ -402,6 +535,8 @@ void VectorObject::Export2EPS(FILE *F, PS_State *PSS) const
 }
 
 
+////////////////////////////////////
+
 
 VectorEllipse::VectorEllipse(float iniBottomRect, float iniTopRect, float iniRightRect, float iniLeftRect)
 {
@@ -415,6 +550,18 @@ VectorEllipse::VectorEllipse(float iniBottomRect, float iniTopRect, float iniRig
 }
 
 
+VectorEllipse::VectorEllipse(const VectorEllipse & VE): vecPen(VE), vecBrush(VE)
+{
+ Tx = NULL;
+ BottomRect = VE.BottomRect;
+ TopRect = VE.TopRect;
+ RightRect = VE.RightRect;
+ LeftRect = VE.LeftRect; 
+ bAngle = VE.bAngle;
+ eAngle = VE.eAngle;
+}
+
+
 VectorEllipse::~VectorEllipse()
 {
   if(Tx)
@@ -422,6 +569,12 @@ VectorEllipse::~VectorEllipse()
 }
 
 
+VectorObject *VectorEllipse::Duplicate(void) const
+{
+  return new VectorEllipse(*this);
+}
+
+
 temp_string VectorEllipse::Export2EPS(PS_State *PSS) const
 {
 string str;
@@ -480,6 +633,16 @@ void VectorEllipse::Transform(const AbstractTransformXY &Tx)
 }
 
 
+VectorObject *VectorPie::Duplicate(void) const
+{
+  VectorEllipse *pVP = new VectorPie(BottomRect,TopRect,RightRect,LeftRect);
+  *(vecPen*)pVP = *(vecPen*)this;
+  *(vecBrush*)pVP = *(vecBrush*)this;
+return pVP;
+}
+
+
+
 temp_string VectorPie::Export2EPS(PS_State *PSS) const
 {
 string str;
@@ -540,6 +703,15 @@ VectorRectangle::~VectorRectangle()
 }
 
 
+VectorObject *VectorRectangle::Duplicate(void) const
+{
+  VectorRectangle *pVR = new VectorRectangle(BottomRect,TopRect,RightRect,LeftRect);
+  *(vecPen*)pVR = *(vecPen*)this;
+  *(vecBrush*)pVR = *(vecBrush*)this;
+return pVR;
+}
+
+
 unsigned VectorRectangle::isInside(float xp, float yp) const
 {
   if(BrushStyle==FILL_NONE) return 0;
@@ -548,7 +720,29 @@ unsigned VectorRectangle::isInside(float xp, float yp) const
     if(xp>LeftRect && xp<RightRect && yp>BottomRect && xp<TopRect) return 2;
     return 1;
   }
-  return 0;  
+  return 0;
+}
+
+
+void VectorRectangle::CalcBoundingBox(FloatBBox &bbx) const
+{
+float rx, ry;
+
+  rx=LeftRect;		ry=BottomRect;
+  if(Tx) Tx->ApplyTransform(rx,ry);
+  UpdateBBox(bbx, 0, rx-PenWidth/2, ry-PenWidth/2, PenWidth, PenWidth);
+
+  rx=RightRect;		ry=BottomRect;
+  if(Tx) Tx->ApplyTransform(rx,ry);
+  UpdateBBox(bbx, 0, rx-PenWidth/2, ry-PenWidth/2, PenWidth, PenWidth);
+
+  rx=RightRect;		ry=TopRect;
+  if(Tx) Tx->ApplyTransform(rx,ry);
+  UpdateBBox(bbx, 0, rx-PenWidth/2, ry-PenWidth/2, PenWidth, PenWidth);
+
+  rx=LeftRect;		ry=TopRect;
+  if(Tx) Tx->ApplyTransform(rx,ry);
+  UpdateBBox(bbx, 0, rx-PenWidth/2, ry-PenWidth/2, PenWidth, PenWidth);
 }
 
 
@@ -620,6 +814,7 @@ void VectorRectangle::Dump2File(FILE *F) const
 #endif
 
 
+
 /////////////////////////////////////////////////////////////
 
 VectorRectangleArc::VectorRectangleArc(float iniBottomRect, float iniTopRect, 
@@ -631,6 +826,15 @@ VectorRectangleArc::VectorRectangleArc(float iniBottomRect, float iniTopRect,
 }
 
 
+VectorObject *VectorRectangleArc::Duplicate(void) const
+{
+  VectorRectangleArc *pVRA = new VectorRectangleArc(BottomRect,TopRect,RightRect,LeftRect,Hradius,Vradius);
+  *(vecPen*)pVRA = *(vecPen*)this;
+  *(vecBrush*)pVRA = *(vecBrush*)this;
+return pVRA;
+}
+
+
 void VectorRectangleArc::Transform(const AbstractTransformXY &Tx)
 {
 float Hr1,Hr2, Vr1,Vr2;
@@ -706,24 +910,12 @@ void VectorRectangleArc::Dump2File(FILE *F) const
 /////////////////////////////////////////////////////////////
 
 
-VectorPolygon::VectorPolygon(float *iniPoints, int iniPointCount)
+/*
+VectorPolygon::VectorPolygon(float *iniPoints, int iniPointCount): VectorLine(iniPoints,iniPointCount)
 {
-  Points = iniPoints;
-  CountPoints = iniPointCount;
-  Close = false;
-  Outline = true;  
-}
-
-
-VectorPolygon::~VectorPolygon()
-{
-  if(Points!=NULL)
-  {
-    free(Points);
-    Points = NULL;
-  }  
-  CountPoints = 0;  
+//  Outline = true;
 }
+*/
 
 
 temp_string VectorPolygon::Export2EPS(PS_State *PSS) const
@@ -734,7 +926,7 @@ string str;
   if(PSS != NULL)
   {
     vecBrush::prepExport(PSS);
-    vecPen::prepExport(PSS);    
+    vecPen::prepExport(PSS);
     PS_Attr(str,PSS);
     if(PSS->PolyFillMode==1 && UpperCont!=NULL && CountPoints>=3)
     {
@@ -791,18 +983,6 @@ const float *pEnd = Points + 2*CountPoints;
 #endif
 
 
-void VectorPolygon::Transform(const AbstractTransformXY &Tx)
-{
-  if(Points==NULL || CountPoints<=0) return;
-
-  const float *pEnd = Points + 2*CountPoints;
-  for(float *p=Points; p<pEnd; p+=2)
-  {  
-    Tx.ApplyTransform(p[0], p[1]);
-  }
-}
-
-
 /*unsigned VectorPolygon::isInside(float xp, float yp) const
 {
   unsigned isX = isInsideX(xp,yp);
@@ -856,10 +1036,10 @@ int OriUpDn = 0;
             }
           }
           TouchLine = true;
-        }        
-      }      
+        }
+      }
       continue;
-    }    
+    }
 
     const float t = (yp-p[1]) / (p[3]-p[1]);
     const float xl = p[0] + (p[2]-p[0])*t;
@@ -878,7 +1058,7 @@ int OriUpDn = 0;
       else
         TouchLine = true;
 
-      OriUpDn = (p[3]>p[1]) ? 1 : -1;            
+      OriUpDn = (p[3]>p[1]) ? 1 : -1;
       continue;
     }
 
@@ -895,7 +1075,7 @@ int OriUpDn = 0;
     {
       if(fabs(yp-pEnd[1])<1e-5 || fabs(yp-Points[1])<1e-5) // Node intersection.
       {
-        Intersects++;        
+        Intersects++;
       }
       else
       {
@@ -963,7 +1143,7 @@ int OriUpDn = 0;
       else
         TouchLine = true;
 
-      OriUpDn = (p[2]>p[0]) ? 1 : -1;            
+      OriUpDn = (p[2]>p[0]) ? 1 : -1;
       continue;
     }
 
@@ -980,7 +1160,7 @@ int OriUpDn = 0;
     {
       if(fabs(xp-pEnd[0])<1e-5 || fabs(xp-Points[0])<1e-5) // Node intersection.
       {
-        Intersects++;        
+        Intersects++;
       }
       else
       {
@@ -998,6 +1178,18 @@ int OriUpDn = 0;
 /////////////////////////////////////////////////////////////
 
 
+void VectorCurve::CalcBoundingBox(FloatBBox &bbx) const
+{
+  if(Points==NULL || CountPoints<=0) return;
+
+  const float *pEnd = Points + 2*CountPoints;
+  for(float *p=Points; p<pEnd; p+=6)
+  {
+    UpdateBBox(bbx,0,p[0], p[1], 0,0);
+  }
+}
+
+
 temp_string VectorCurve::Export2EPS(PS_State *PSS) const
 {
 string str;
@@ -1094,7 +1286,7 @@ VectorLine::VectorLine(int iniPointCount)
     CountPoints = 0;
     return;
   }
-  Points = (float*)malloc(sizeof(float)*4);
+  Points = (float*)malloc(sizeof(float)*iniPointCount*2);
   CountPoints = iniPointCount;
 }
 
@@ -1107,6 +1299,27 @@ VectorLine::VectorLine(float *iniPoints, int iniPointCount)
 }
 
 
+VectorLine::VectorLine(const VectorLine &VL): vecPen(VL)
+{
+  if(VL.CountPoints>0 && VL.Points!=NULL)
+  {
+    Points = (float*)malloc(sizeof(float)*VL.CountPoints*2);
+    if(Points)
+    {
+      CountPoints = VL.CountPoints;
+      memcpy(Points, VL.Points, sizeof(float)*CountPoints*2);
+    }
+    else
+      CountPoints = 0;
+  }
+  else
+  {
+    CountPoints = 0;
+    Points = NULL;
+  }
+}
+
+
 VectorLine::~VectorLine()
 {
   if(Points!=NULL)
@@ -1114,7 +1327,25 @@ VectorLine::~VectorLine()
     free(Points);
     Points = NULL;
   }  
-  CountPoints = 0;  
+  CountPoints = 0;
+}
+
+
+void VectorLine::CalcBoundingBox(FloatBBox &bbx) const
+{
+  if(Points==NULL || CountPoints<=0) return;
+
+  const float *pEnd = Points + 2*CountPoints;
+  for(float *p=Points; p<pEnd; p+=2)
+  {
+    UpdateBBox(bbx,0,p[0], p[1], 0,0);
+  }
+}
+
+
+VectorObject *VectorLine::Duplicate(void) const
+{
+  return new VectorLine(*this);
 }
 
 
@@ -1173,7 +1404,7 @@ void VectorLine::Transform(const AbstractTransformXY &Tx)
 /////////////////////////////////////////////////////////////
 
 
-void PsBlob::FeaturesEPS(unsigned & Feature) const
+void PsBlob::FeaturesEPS(uint32_t & Feature) const
 {
   if(Blob==NULL) return;
   if(StrStr(Blob,"DrawEllipse")!=NULL) Feature |= EPS_DrawElipse;
@@ -1182,6 +1413,12 @@ void PsBlob::FeaturesEPS(unsigned & Feature) const
 }
 
 
+VectorObject *PsBlob::Duplicate(void) const
+{
+  return new PsBlob(strdup(Blob));
+}
+
+
 /////////////////////////////////////////////////////////////
 
 
@@ -1208,6 +1445,30 @@ VectorObject *IterObject = FirstObject;
 }
 
 
+void VectorList::CalcBoundingBox(FloatBBox &bbx) const
+{
+VectorObject *IterObject = FirstObject;
+  while(IterObject!=NULL)
+  {
+    IterObject->CalcBoundingBox(bbx);
+    IterObject = IterObject->NextObject;
+  }
+}
+
+
+VectorObject *VectorList::Duplicate(void) const
+{
+  VectorList *pVL = new VectorList();
+  VectorObject *ItObjs = FirstObject;
+  while(ItObjs!=NULL)
+  {
+    pVL->AddObject(ItObjs->Duplicate());
+    ItObjs = ItObjs->NextObject;
+  }
+return pVL;
+}
+
+
 temp_string VectorList::Export2EPS(PS_State *PSS) const
 {
 string str;
@@ -1236,7 +1497,7 @@ VectorObject *IterObject = FirstObject;
 #endif
 
 
-void VectorList::FeaturesEPS(unsigned & Feature) const
+void VectorList::FeaturesEPS(uint32_t & Feature) const
 {
 VectorObject *IterObject = FirstObject;
 
@@ -1280,6 +1541,7 @@ void VectorList::AddObject(VectorObject *NewObj)
 
 void VectorList::Append(VectorList &VectList)
 {
+  if(VectList.FirstObject==NULL || VectList.VectorObjects==0) return;	// listto append is empty.
   if(FirstObject==NULL)
   {
     FirstObject = VectList.FirstObject;
@@ -1293,7 +1555,7 @@ void VectorList::Append(VectorList &VectList)
     VectorObjects += VectList.VectorObjects;
   }
   VectList.FirstObject = VectList.LastObject = NULL;
-  VectList.VectorObjects = 0;    
+  VectList.VectorObjects = 0;
 }
 
 
@@ -1328,9 +1590,9 @@ const int count = VectorObjects;
 /////////////////////////////////////////////////////////////
 
 
-VectorImage::VectorImage(VectorList &VecList, const PS_State & NewPSS)
+VectorImage::VectorImage(VectorList &VecList, const PS_State & NewPSS): PSS(NewPSS)
 {
-  PSS = NewPSS;
+  //PSS = NewPSS;
   UsageCount = 0;
   FirstObject = VecList.FirstObject;	VecList.FirstObject = NULL;
   LastObject = VecList.LastObject;	VecList.LastObject = NULL;
@@ -1347,8 +1609,8 @@ VectorImage::VectorImage(VectorList &VecList, const PS_State & NewPSS)
 
 VectorImage::VectorImage()
 {
+  // PSS member object has its own ctor.
   UsageCount = 0;
-  memset(&PSS, 0, sizeof(PSS));
 }
 
 
@@ -1385,6 +1647,28 @@ TextContainer::~TextContainer()
 }
 
 
+VectorObject *TextContainer::Duplicate(void) const
+{
+  TextContainer *pTC = new TextContainer();
+  pTC->PosX = PosX;
+  pTC->PosY = PosY;
+  pTC->FontOrientation = FontOrientation;	///< Font rotation [deg]
+  pTC->RotCenterX = RotCenterX;
+  pTC->RotCenterY = RotCenterY;
+  pTC->TextAllign = TextAllign;
+  pTC->MixMode = MixMode;
+  if(Text!=NULL)
+  {
+    pTC->Text = (TextObject**)malloc(sizeof(TextObject*)*TextObjects);
+    for(int i=0; i<TextObjects; i++)
+    {
+      pTC->Text[i] = (Text[i]==NULL) ? NULL : new TextObject(*Text[i]);
+    }
+  }
+return pTC;
+}
+
+
 /// This function discards all accents from a postscript text line.
 /// Such line could be used for metrics calculation.
 temp_string ExtractAccents(const string &LineStr)
@@ -1426,7 +1710,7 @@ void AppendShow(string &str, string &strLine, const unsigned char HorizontalPos,
       }
     }
 
-  switch((HorizontalPos & 6))   
+  switch((HorizontalPos & 6))
     {
     case 2: if(strstr(strLine,") show (")!=NULL)		// TA_RIGHT
 	    {
@@ -1564,7 +1848,7 @@ string Override;
 	  *ScanS2 = '\n';
 	  ScanS = ScanS2 + 1;
 
-	  CurPosY -= 1.01 * Text[i]->size*2.66f;
+	  CurPosY -= 1.01f * Text[i]->size*2.66f;
 	  AppendShow(str,strLine,TextAllign,Override);
 	  str.cat_printf(" newpath %2.2f %2.2f moveto", CurPosX, CurPosY);
 	}
@@ -1646,14 +1930,14 @@ float LastLineSz = 0;
 	               TextHeight += LastLineSz;
 		       break;
 	    case 'l':
-	    case 'i':  CurPosX += 0.26 * LastLineSz;
+	    case 'i':  CurPosX += 0.26f * LastLineSz;
 		       break;
-	    case 'm':  CurPosX += 0.71 * LastLineSz;
+	    case 'm':  CurPosX += 0.71f * LastLineSz;
 		       break;
             default:   if(isupper(ch))
-		         CurPosX += 0.5 * LastLineSz;
+		         CurPosX += 0.5f * LastLineSz;
 		       else
-                         CurPosX += 0.44 * LastLineSz;
+                         CurPosX += 0.44f * LastLineSz;
 		       break;
 	  }
 	  j++;
@@ -1675,7 +1959,7 @@ void TextContainer::Dump2File(FILE *F) const
       if(Text[i]!=NULL)
       {
       fprintf(F,"FontSz=%f;", Text[i]->size);
-      fprintf(F,"%s\"%s\"", (i==0)?"":",", Text[i]->contents);
+      fprintf(F,"%s\"%s\"", (i==0)?"":",", Text[i]->contents());
       }
     }
   fputs("}\n",F);
@@ -1768,14 +2052,14 @@ bool TextContainer::isEmpty(void) const
 }
 
 
-static void CheckAccent(unsigned & Feature, const char *PS_text)
+static void CheckAccent(uint32_t & Feature, const char *PS_text)
 {
   if(PS_text==NULL) return;
   if(StrStr(PS_text,"accentshow")!=NULL)  Feature |= EPS_accentshow;
   if(StrStr(PS_text,"ACCENTSHOW")!=NULL)  Feature |= EPS_ACCENTSHOW;
 }
 
-void TextContainer::FeaturesEPS(unsigned & Feature) const
+void TextContainer::FeaturesEPS(uint32_t & Feature) const
 {
   CheckAccent(Feature, Export2EPS()());
 }
@@ -2032,11 +2316,11 @@ float Distance;
 
     case FILL_DIAG_UPx:Distance = PSS->HatchDistance;
 		       goto FINALDiagonal;
-    case FILL_DIAG_UP: Distance = 2.8;
+    case FILL_DIAG_UP: Distance = 2.8f;
 		       goto FINALDiagonal;
-    case FILL_DIAG_UP2:Distance = 5.7;
+    case FILL_DIAG_UP2:Distance = 5.7f;
 		       goto FINALDiagonal;
-    case FILL_DIAG_UP4:Distance = 11.3;
+    case FILL_DIAG_UP4:Distance = 11.3f;
 FINALDiagonal:	       tmp.printf("\n%2.2f %2.1f %2.2f {%2.2f moveto %2.2f %2.2f rlineto}",  // Diagonal up
 			       MinPolyX-(MaxPolyY-MinPolyY),Distance,MaxPolyX,MinPolyY,
 			       MaxPolyY-MinPolyY, MaxPolyY-MinPolyY  );
@@ -2044,11 +2328,11 @@ FINALDiagonal:	       tmp.printf("\n%2.2f %2.1f %2.2f {%2.2f moveto %2.2f %2.2f
 
     case FILL_DIAG_CROSSHATCHx:Distance = PSS->HatchDistance;
 		       goto FINALCross;
-    case FILL_DIAG_CROSSHATCH:Distance=2.8;
+    case FILL_DIAG_CROSSHATCH:Distance=2.8f;
 		       goto FINALCross;
-    case FILL_DIAG_CROSSHATCH2:Distance=5.7;
+    case FILL_DIAG_CROSSHATCH2:Distance=5.7f;
 		       goto FINALCross;
-    case FILL_DIAG_CROSSHATCH4:Distance=11.3;
+    case FILL_DIAG_CROSSHATCH4:Distance=11.3f;
 FINALCross:	       tmp.printf("\n%2.2f %2.1f %2.2f {%2.2f moveto %2.2f %2.2f rlineto}for",
 			       MinPolyX-(MaxPolyY-MinPolyY),Distance,MaxPolyX,MinPolyY,
 			       MaxPolyY-MinPolyY, MaxPolyY-MinPolyY );
@@ -2102,14 +2386,14 @@ FINALDot:		tmp.printf("\n[0.5 %2.1f] 0 setdash\n %2.2f %2.1f %2.2f {%2.2f moveto
     case FILL_GRAY_75:Distance=0.75;
 			goto FINALDot;
 
-    case FILL_DIAG_DOWN:Distance=2.8;
+    case FILL_DIAG_DOWN:Distance=2.8f;
 FinalDiagDown:		tmp.printf("\n%2.2f %2.1f %2.2f {%2.2f moveto %2.2f %2.2f rlineto}",
 			       MinPolyX,Distance,(MaxPolyX+(MaxPolyY-MinPolyY)), MinPolyY,
 			       -(MaxPolyY-MinPolyY), MaxPolyY-MinPolyY);
 			goto FINALLY;
-    case FILL_DIAG_DOWN2:Distance = 5.7;
+    case FILL_DIAG_DOWN2:Distance = 5.7f;
 			goto FinalDiagDown;
-    case FILL_DIAG_DOWN4:Distance = 11.4;
+    case FILL_DIAG_DOWN4:Distance = 11.4f;
 			goto FinalDiagDown;
     case FILL_DIAG_DOWNx:Distance=PSS->HatchDistance;
 			goto FinalDiagDown;
@@ -2162,6 +2446,24 @@ FillPattern:		PSData+="\ngsave clip\n"
 			goto FillPattern;
     case FILL_BALLS:	tmp = "BallsFill";
 			goto FillPattern;
+    case FILL_BRICKS:	tmp = "BrickFill";
+			goto FillPattern;
+    case FILL_DIAG_BRICKS:tmp = "DiagBrickFill";
+			goto FillPattern;
+    case FILL_HONEYCOMB:tmp = "HoneycombFill";
+			goto FillPattern;
+    case FILL_FISHSCALE:tmp = "FishscaleFill";
+			goto FillPattern;
+    case FILL_ARCH:	tmp = "ArchFill";
+			goto FillPattern;
+    case FILL_CHAINLINK:tmp = "ChainlinkFill";
+			goto FillPattern;
+    case FILL_PATIO:	tmp = "PatioFill";
+			goto FillPattern;
+    case FILL_WEAVE:	tmp = "WeaveFill";
+			goto FillPattern;
+    case FILL_WAVES:	tmp = "WavesFill";
+			goto FillPattern;
     case FILL_TARTAN:	Distance=10;
 			PSData += '\n';
 			if(PSS->LineStyle!=0) PSData+="gsave";
