@@ -1,5 +1,5 @@
 /***************************************************************************
- * Unit:    rasimg library 0.23                                            *
+ * Unit:    rasimg library 0.25                                            *
  * Purpose: Prototypes for general manipulation vith vector images         *
  * Modul:   vecimage.h                                                     *
  * Licency: GPL or LGPL                                                    *
@@ -9,7 +9,7 @@
 #define _VECIMAGE_H_
 
 #include "stringa.h"
-#include "raster.h"
+#include "image.h"
 
 
 #define PSS_LineColor	 1
@@ -19,7 +19,7 @@
 #define PSS_LineCap	16
 #define PSS_LineJoin	32
 
-#define mm2PSu(x)   ( (float)(x)*71/25.4 )
+#define mm2PSu(x)   ( (float)(x)*71/25.4f )
 
 
 void Font2PS(string & Text, const float FontSize, const char *FontName="Times-Roman");
@@ -35,7 +35,7 @@ typedef enum
   FILL_SOLID = 1,		// Solid
   FILL_DIAG_UP = 2,		// Finely spaced 45-degree lines
   FILL_DIAG_UP2 = 3,		// Medium spaced 45-degree lines
-  FILL_DIAG_UP4 = 4,            // Coarsely spaced 45-degree lines
+  FILL_DIAG_UP4 = 4,		// Coarsely spaced 45-degree lines
   FILL_DIAG_CROSSHATCH = 5,	// Fine 45-degree hatching
   FILL_DIAG_CROSSHATCH2 = 6,	// Medium 45-degree hatching
   FILL_DIAG_CROSSHATCH4 = 7,	// Coarse 45-degree hatching
@@ -80,7 +80,16 @@ typedef enum
   FILL_BALLS = 109,
   FILL_TARTAN = 110,
   FILL_TRIANGLES = 111,
-  FILL_SM_SQUARES = 112
+  FILL_SM_SQUARES = 112,
+  FILL_BRICKS = 113,
+  FILL_DIAG_BRICKS = 114,
+  FILL_HONEYCOMB = 115,
+  FILL_FISHSCALE = 116,
+  FILL_ARCH = 117,
+  FILL_CHAINLINK = 118,
+  FILL_PATIO = 119,
+  FILL_WEAVE = 120,
+  FILL_WAVES = 121
 } E_FILL_STYLES;
 
 
@@ -92,18 +101,18 @@ typedef struct
 	float LineWidth;
 	float HatchDistance;		///< PSu
 
-	WORD FontWeight;
-	SWORD FontOrientation10;	///< Text rotation request.        
+	uint16_t FontWeight;
+	int16_t FontOrientation10;	///< Text rotation request.
         
 	char FontItallic;
 	char dirty;
-	BYTE FillPattern;
-        BYTE FillTransparency;
-	BYTE LineStyle;
-	BYTE LineCap;			///< 0-butt caps, 1-round caps, 2-extended butt caps.
-	BYTE LineJoin;			///< 0-miter join, 1-round join, 2-bevel join.
-        BYTE PolyFillMode;		///< 0-standard; 1-alternating
-	BYTE TextAllign;		///< 0-TA_LEFT; 2-TA_RIGHT; 6-TA_CENTER
+	uint8_t FillPattern;
+        uint8_t FillTransparency;
+	uint8_t LineStyle;
+	uint8_t LineCap;			///< 0-butt caps, 1-round caps, 2-extended butt caps.
+	uint8_t LineJoin;			///< 0-miter join, 1-round join, 2-bevel join.
+        uint8_t PolyFillMode;		///< 0-standard; 1-alternating
+	uint8_t TextAllign;		///< 0-TA_LEFT; 2-TA_RIGHT; 6-TA_CENTER
 
 	RGB_Record FillColor;	
         RGB_Record FillBackground;
@@ -119,10 +128,11 @@ class PS_State: public PS_StateC
 {
 public:
 	PS_State(void);
+	PS_State(const PS_State &PSS);
 	~PS_State(void);
 	PS_State &operator=(const PS_State & OrigPSS);
 	void AttachPalette(APalette *NewPalette);
-        void AttachRaster(Raster2DAbstract *NewRaster);
+	void AttachRaster(Raster2DAbstract *NewRaster);
 
 	RGB_Record PaperBackground;
 	string FontName;
@@ -154,6 +164,19 @@ public:
 };
 
 
+/// Square bounding box.
+typedef struct
+{
+  float MinX;
+  float MaxX;
+  float MinY;
+  float MaxY;
+} FloatBBox;
+
+void InitBBox(FloatBBox & bbx);
+void UpdateBBox(FloatBBox & bbx, float alpha, float x, float y, float dx, float dy);
+void UpdateBBox(FloatBBox & bbx, const AbstractTransformXY *Tr, const FloatBBox & bbxIn);
+
 
 ///////////////////////////////////////////////////////////
 
@@ -212,7 +235,7 @@ public:
   vecBrush(const PS_State &PSS);
 
   virtual void prepExport(PS_State *PSS) const;
-  virtual void FeaturesEPS(unsigned & Feature) const;
+  virtual void FeaturesEPS(uint32_t & Feature) const;
   virtual int getAttribType(void) const {return ATTR_BRUSH;};
   void AttribFromPSS(const PS_State &PSS);
 };
@@ -228,8 +251,8 @@ public:
   const CpTranslator *ConvertCpg;
   RGB_Record TextColor;
   float FontSize, FontSizeW;
-  WORD Weight;
-  SWORD FontOrientation10;
+  uint16_t Weight;
+  int16_t FontOrientation10;
   char Italic;
 };
 
@@ -290,9 +313,11 @@ class VectorObject
 public:
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const {return temp_string();}
   virtual void Export2EPS(FILE *F, PS_State *PSS) const;
+  virtual void CalcBoundingBox(FloatBBox &bbx) const {}
   virtual void Transform(const AbstractTransformXY &Tx) {}
-  virtual void FeaturesEPS(unsigned & Feature) const {return;}
+  virtual void FeaturesEPS(uint32_t & Feature) const {return;}
   virtual unsigned isInside(float xp, float yp) const {return 0;}
+  virtual VectorObject *Duplicate(void)const = 0;
 #ifdef _DEBUG
   virtual void Dump2File(FILE *F) const {}
 #endif
@@ -312,7 +337,8 @@ public:
 
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const {return temp_string(Blob);}
   //virtual void Transform(const AbstractTransformXY &Tx) {}
-  virtual void FeaturesEPS(unsigned & Feature) const;
+  virtual void FeaturesEPS(uint32_t & Feature) const;
+  virtual VectorObject *Duplicate(void) const;
   virtual ~PsBlob() {NextObject=NULL; if(Blob) {free(Blob);Blob=NULL;}}
   PsBlob(char *IniBlob) {Blob=IniBlob;}
 };
@@ -324,7 +350,7 @@ class VectorList: public VectorObject
 public:
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   void Export2EPS(FILE *F, PS_State *PSS=NULL) const;
-  virtual void FeaturesEPS(unsigned & Feature) const;
+  virtual void FeaturesEPS(uint32_t & Feature) const;
 #ifdef _DEBUG
   virtual void Dump2File(FILE *F) const;
 #endif
@@ -332,9 +358,11 @@ public:
   virtual ~VectorList();
 
   void AddObject(VectorObject *NewObj);
+  virtual void CalcBoundingBox(FloatBBox &bbx) const;
   virtual void Transform(const AbstractTransformXY &Tx);
   void Append(VectorList &VectList);
   void Swap(VectorList &VectList);
+  virtual VectorObject *Duplicate(void) const;
 
   VectorObject *FirstObject;
   VectorObject *LastObject;
@@ -346,12 +374,14 @@ class VectorEllipse: public VectorObject, public vecPen, public vecBrush
 {
 public:
   VectorEllipse(float iniBottomRect, float iniTopRect, float iniRightRect, float iniLeftRect);
+  VectorEllipse(const VectorEllipse & VE);
   virtual ~VectorEllipse();
 
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   virtual void Transform(const AbstractTransformXY &Tx);
-  virtual void FeaturesEPS(unsigned & Feature) const  {Feature|=EPS_DrawElipse; vecBrush::FeaturesEPS(Feature);}
+  virtual void FeaturesEPS(uint32_t & Feature) const  {Feature|=EPS_DrawElipse; vecBrush::FeaturesEPS(Feature);}
   void AttribFromPSS(const PS_State &PSS) {vecPen::AttribFromPSS(PSS);vecBrush::AttribFromPSS(PSS);}
+  virtual VectorObject *Duplicate(void) const;
 
   vecTransform *Tx;
   int bAngle, eAngle;
@@ -362,6 +392,8 @@ public:
 class VectorPie: public VectorEllipse
 {
 public:
+  virtual VectorObject *Duplicate(void) const;
+
   VectorPie(float iniBottomRect, float iniTopRect, float iniRightRect, float iniLeftRect): VectorEllipse(iniBottomRect,iniTopRect,iniRightRect,iniLeftRect) {}
 
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
@@ -373,16 +405,19 @@ class VectorLine: public VectorObject, public vecPen
 public:
   VectorLine(int iniPointCount);
   VectorLine(float *iniBottomRect, int iniPointCount);
+  VectorLine(const VectorLine &VL);
   virtual ~VectorLine();
 
+  virtual void CalcBoundingBox(FloatBBox &bbx) const;
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   virtual void Transform(const AbstractTransformXY &Tx);
+  virtual VectorObject *Duplicate(void) const;
 #ifdef _DEBUG
   virtual void Dump2File(FILE *F) const;
 #endif
 
   int CountPoints;
-  float *Points;  	///< x, y coordinate list of the line.
+  float *Points;	///< x, y coordinate list of the line.
   bool Close;
 };
 
@@ -392,25 +427,29 @@ class VectorCurve: public VectorLine, public vecBrush
 public:
   VectorCurve(int iniPointCount): VectorLine(iniPointCount) {Filled=false;};
   VectorCurve(float *iniBottomRect, int iniPointCount): VectorLine(iniBottomRect,iniPointCount) {Filled=false;};
+  VectorCurve(const VectorCurve &VC): VectorLine(VC), vecBrush(VC) {Filled=VC.Filled;}
 
+  virtual void CalcBoundingBox(FloatBBox &bbx) const;
   void AttribFromPSS(const PS_State &PSS) {vecPen::AttribFromPSS(PSS);vecBrush::AttribFromPSS(PSS);}
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
 
-  bool Filled;
+  bool Filled;		// This should be replaced with BrushStyle=FILL_NONE.
 };
 
 
-class VectorPolygon: public VectorObject, public vecPen, public vecBrush
+class VectorPolygon: public VectorLine, public vecBrush
 {
 public:
-  VectorPolygon(float *iniBottomRect, int iniPointCount);
-  virtual ~VectorPolygon();
+  VectorPolygon(float *iniPoints, int iniPointCount): VectorLine(iniPoints,iniPointCount) {};
+  VectorPolygon(const VectorPolygon &VP): VectorLine(VP), vecBrush(VP) {}
+  //virtual ~VectorPolygon();			// DTOR form VectorLine is sufficient enough.
 
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
-  virtual void Transform(const AbstractTransformXY &Tx);
+  //virtual void Transform(const AbstractTransformXY &Tx);	// Inherited from VectorLine.
   virtual unsigned isInside(float xp, float yp) const;
   void AttribFromPSS(const PS_State &PSS) {vecPen::AttribFromPSS(PSS);vecBrush::AttribFromPSS(PSS);}
-  virtual void FeaturesEPS(unsigned & Feature) const  {vecBrush::FeaturesEPS(Feature);}
+  virtual void FeaturesEPS(uint32_t & Feature) const  {vecBrush::FeaturesEPS(Feature);}
+  virtual VectorObject *Duplicate(void) const {return new VectorPolygon(*this);}
 #ifdef _DEBUG
   virtual void Dump2File(FILE *F) const;
 #endif
@@ -418,10 +457,7 @@ public:
   //unsigned isInsideX(float xp, float yp) const;
   //unsigned isInsideY(float xp, float yp) const;
 
-  int CountPoints;
-  float *Points;  
-  bool Close;
-  bool Outline;  
+  //bool Outline;		// No need for this property, Linestyle=0 is sufficient enough.
 };
 
 
@@ -431,10 +467,12 @@ public:
   VectorRectangle(float iniBottomRect, float iniTopRect, float iniLeftRect, float iniRightRect);
   ~VectorRectangle();
 
+  virtual void CalcBoundingBox(FloatBBox &bbx) const;
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   virtual void Transform(const AbstractTransformXY &Tx);
   virtual unsigned isInside(float xp, float yp) const;
   void AttribFromPSS(const PS_State &PSS) {vecPen::AttribFromPSS(PSS);vecBrush::AttribFromPSS(PSS);}
+  virtual VectorObject *Duplicate(void) const;
 #ifdef _DEBUG
   void Dump2File(FILE *F) const;
 #endif
@@ -452,6 +490,7 @@ public:
 
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   virtual void Transform(const AbstractTransformXY &Tx);
+  virtual VectorObject *Duplicate(void) const;
 #ifdef _DEBUG
   void Dump2File(FILE *F) const;
 #endif
@@ -464,9 +503,12 @@ public:
 class TextObject
 {
 public:
+  TextObject(void) {}
+  TextObject(const TextObject&TC): TargetFont(TC.TargetFont), contents(TC.contents), size(TC.size), TextColor(TC.TextColor) {}
+
   string TargetFont;
   string contents;
-  //WORD Weight;
+  //uint16_t Weight;
   //char Itallic;
   float size;			///< Size of font in [mm].
   RGB_Record TextColor;
@@ -479,15 +521,16 @@ public:
   float PosX, PosY;		///< Tex start point.
   float FontOrientation;	///< Font rotation [deg]
   float RotCenterX, RotCenterY;
-  BYTE TextAllign;
-  BYTE MixMode;			///< 1 Transparent; 2 Opaque
+  uint8_t TextAllign;
+  uint8_t MixMode;		///< 1 Transparent; 2 Opaque
 
   TextContainer();
-  virtual ~TextContainer();  
+  virtual ~TextContainer();
 
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
   virtual void Transform(const AbstractTransformXY &Tx);
-  virtual void FeaturesEPS(unsigned & Feature) const;
+  virtual void FeaturesEPS(uint32_t & Feature) const;
+  virtual VectorObject *Duplicate(void) const;
 #ifdef _DEBUG
   void Dump2File(FILE *F) const;
 #endif
@@ -531,12 +574,15 @@ public:
   VectorRaster(float iniBottomRect, float iniTopRect, float iniRightRect, float iniLeftRect);
   VectorRaster(float iniCenterX, float iniCenterY, float dx, float dy, float alpha);
   VectorRaster(Raster2DAbstract *iniRaster, float iniCenterX, float iniCenterY, float TrDx, float TrDy, float alpha);
+  VectorRaster(const VectorRaster& VR);
   virtual ~VectorRaster();
 
-  virtual temp_string Export2EPS(PS_State *PSS=NULL) const;  
+  virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
+  virtual void CalcBoundingBox(FloatBBox &bbx) const;
   virtual void Export2EPS(FILE *F, PS_State *PSS=NULL) const;
   virtual void Transform(const AbstractTransformXY &Tx);
-  virtual void FeaturesEPS(unsigned & Feature) const;
+  virtual void FeaturesEPS(uint32_t & Feature) const;
+  virtual VectorObject *Duplicate(void) const;
 
   void AttachRaster(Raster2DAbstract *NewRaster);
   void AttachPalette(APalette *NewPalette);
