@@ -73,7 +73,7 @@ VectorRaster::VectorRaster(float iniCenterX, float iniCenterY, float dx, float d
   RightCenterY = iniCenterY + dx*sin(alpha);
 
   TopCenterX = iniCenterX + dy*sin(alpha);
-  TopCenterY = iniCenterY + dy*cos(alpha);  
+  TopCenterY = iniCenterY + dy*cos(alpha);
 }
 
 
@@ -88,6 +88,19 @@ VectorRaster::VectorRaster(float iniBottomRect, float iniTopRect, float iniRight
 }
 
 
+VectorRaster::VectorRaster(const VectorRaster& VR)
+{
+  CenterX = VR.CenterX;
+  CenterY = VR.CenterY;
+  RightCenterX = VR.RightCenterX;
+  RightCenterY = VR.RightCenterY;
+  TopCenterX = VR.TopCenterX;
+  TopCenterY = VR.TopCenterY;
+  AttachRaster(VR.Raster);
+  AttachPalette(VR.Palette);
+}
+
+
 VectorRaster::~VectorRaster()
 {
   AttachRaster(NULL);
@@ -95,6 +108,12 @@ VectorRaster::~VectorRaster()
 }
 
 
+VectorObject *VectorRaster::Duplicate(void) const
+{
+  return new VectorRaster(*this);
+}
+
+
 void VectorRaster::AttachRaster(Raster2DAbstract *NewRaster)
 {
   if(Raster==NewRaster) return;		// Raster is already attached
@@ -125,7 +144,7 @@ void VectorRaster::AttachPalette(APalette *NewPalette)
 }
 
 
-void VectorRaster::FeaturesEPS(unsigned & Feature) const
+void VectorRaster::FeaturesEPS(uint32_t & Feature) const
 {
 int ColorMode = ImageType();
   if(ColorMode==ImagePalette)
@@ -305,7 +324,7 @@ char RasterPlanes;
 	  {
 	  if(RasterPlanes==8)  //speedup trick for 8 planes
 	    {
-	    BYTE *ptrb = (BYTE *)Raster->GetRow(Y);
+	    uint8_t *ptrb = (uint8_t *)Raster->GetRow(Y);
 	    for(X=0; X<BytesPerLine; X++)
 		{
 		Palette->Get(*ptrb++,&RGB);
@@ -319,7 +338,7 @@ char RasterPlanes;
 	     if(RasLine)
 	       for(X=0; X<RasLine->GetSize1D(); X++)
 		  {
-		  BYTE b = RasLine->GetValue1D(X);
+		  uint8_t b = RasLine->GetValue1D(X);
 		  Palette->Get(b,&RGB);
 		  fprintf(f,"%.2X%.2X%.2X",
 		     (int)RGB.R, (int)RGB.G, (int)RGB.B);
@@ -334,7 +353,7 @@ char RasterPlanes;
 	     Raster1DAbstract *RasLine = Raster->GetRowRaster(Y);	  
 	     if(RasLine)
 	       {
-	       DWORD w;
+	       uint32_t w;
 	       for(X=0;X<RasLine->GetSize1D();X++)
 		 {
 	         w = RasLine->GetValue1D(X);	      
@@ -350,7 +369,7 @@ char RasterPlanes;
 	   RasterPlanes==4 ||
 	   RasterPlanes==1)	//speedup trick for 8, 4 and 1 planes
 	 {
-FAST_COPY:BYTE *ptrb = (BYTE *)Raster->GetRow(Y);
+FAST_COPY:uint8_t *ptrb = (uint8_t *)Raster->GetRow(Y);
 	 for(X=0; X<BytesPerLine; X++)
 	    {
 	    fprintf(f,"%.2X",(unsigned)*ptrb++);
@@ -362,7 +381,7 @@ FAST_COPY:BYTE *ptrb = (BYTE *)Raster->GetRow(Y);
 	 if(RasLine)
 	   {
 	   int k = RasterPlanes - 8;
-	   DWORD w;
+	   uint32_t w;
 	   for(X=0;X<RasLine->GetSize1D();X++)
 	   {
 	     w = RasLine->GetValue1D(X);
@@ -386,6 +405,13 @@ FAST_COPY:BYTE *ptrb = (BYTE *)Raster->GetRow(Y);
 }
 
 
+void VectorRaster::CalcBoundingBox(FloatBBox &bbx) const
+{
+  UpdateBBox(bbx, 0, CenterX+(RightCenterX-CenterX), CenterY+(TopCenterY-CenterY), 0, 0); // Upper right corner
+  UpdateBBox(bbx, 0, CenterX-(RightCenterX-CenterX), CenterY-(TopCenterY-CenterY), 0, 0); // Lower left corner
+}
+
+
 void VectorRaster::Export2EPS(FILE *f, PS_State *PSS) const
 {
 float RotAngle;
