@@ -21,8 +21,10 @@
  #include <unistd.h>
 #endif
 
-#include"wp2latex.h"
 #include"images/raster.h"
+
+#include"wp2latex.h"
+
 #include "cp_lib/cptran.h"
 
 extern string latex_filename;
@@ -83,7 +85,7 @@ typedef struct save	// property save structure
     RDS rds;		// Rtf Destination State
     RIS ris;		// Rtf Internal State
     RGBQuad RGB;	// The color of the current block
-    BYTE Cols;		// Number of columns inside current block
+    uint8_t Cols;		// Number of columns inside current block
     bool fSkipDestIfUnk;
 
     const CpTranslator *ConvertCpg; //Code page related to a current font selected
@@ -146,7 +148,7 @@ typedef struct 		//symbol
 class TconvertedPass1_RTF: public TconvertedPass1
        {
 public:CpTranslator *Unicode;
-       BYTE ForcedTranslator;
+       uint8_t ForcedTranslator;
        string Keyword,Parameter;
        char KeywordType;
        bool isParam;
@@ -289,7 +291,7 @@ RGBQuad RHT_Highlight[17]={
 static void HEX2BIN_Block(FILE *FileIn, FILE *FileOut)
 {
 char c;
-BYTE HEX;
+uint8_t HEX;
 
   while(!feof(FileIn))
       {
@@ -492,9 +494,10 @@ static int ecParseChar(TconvertedPass1_RTF *cq, int ch)
 			   CharacterStr(cq,Ext_chr_str(ch,cq,cq->ConvertCpg));
 			   return(ecOK);
 		   }
-    default:      // handle other destinations....
-		  return ecOK;
+    default:      // Handle other destinations.
+		  break;
     }
+return ecOK;
 }
 
 
@@ -1404,7 +1407,7 @@ static void UnicodeSymbol(TconvertedPass1_RTF *cq)
   fprintf(cq->log,"\n#UnicodeSymbol() ");fflush(cq->log);
 #endif
 char dummy[10];
-DWORD pos;
+uint32_t pos;
 int ch;
 
   pos = ftell(cq->wpd);		// remove \' that follows imediatelly after \u
@@ -1449,7 +1452,7 @@ static void SpecialObject(TconvertedPass1_RTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#SpecialObject() ");fflush(cq->log);
 #endif
-DWORD FilePos;
+uint32_t FilePos;
 string ObjectName,Type;
 char c;
 
@@ -1996,7 +1999,7 @@ int TconvertedPass1_RTF::Convert_first_pass()
 #ifdef DEBUG
   fprintf(log,"\n#Convert_pass1_RTF() ");fflush(log);
 #endif
-DWORD fsize;
+uint32_t fsize;
 
   if(Verbosing >= 1)
      printf(_("\n>>>RTF2LaTeX<<< Conversion program: From RTF to LaTeX Version %s\n"
@@ -2053,10 +2056,10 @@ DWORD fsize;
 
 ////////////////////Unicode stuff///////////////////////
 
-static void ProcessUnicode(TconvertedPass1 *cq, DWORD (*CharReader)(FILE *F), int Increment=0, const char *MESSAGE="UNICODE")
+static void ProcessUnicode(TconvertedPass1 *cq, uint32_t (*CharReader)(FILE *F), int Increment=0, const char *MESSAGE="UNICODE")
 {
-DWORD fsize;
-DWORD WChar;
+uint32_t fsize;
+uint32_t WChar;
 
  if(CharReader==NULL) return;  //a serious problem occured
 
