@@ -18,6 +18,75 @@
 #include "cp_lib/cptran.h"
 
 
+// See: https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Complete_list_of_MIME_types
+const TMimeItem MimeList[] =
+{
+  {"data:image/bmp;base64", 21, ".bmp"},
+  {"data:image/gif;base64", 21, ".gif"},
+  {"data:image/jpg;base64", 21, ".jpg"},
+  {"data:image/jpeg;base64",22, ".jpg"},
+  {"data:image/png;base64", 21, ".png"},
+  {"data:image/svg+xml;base64", 25, ".svg"},
+  {"data:image/tiff;base64",22, ".tif"},
+  {"data:image/tif;base64", 21, ".tif"}
+};
+
+
+// static const char *base64_chars = 
+//             "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+//             "abcdefghijklmnopqrstuvwxyz"
+//             "0123456789+/";
+uint8_t FindBase64(char ch)
+{
+  if(ch>='A' && ch<='Z') return ch - 'A';
+  if(ch>='a' && ch<='z') return ch - 'a' + 'Z'-'A'+1;
+  if(ch>='0' && ch<='9') return ch - '0' + 2*('Z'-'A')+2;
+  if(ch=='+') return 2*('Z'-'A')+2 + 10;  
+  if(ch=='/') return 2*('Z'-'A')+2 + 11;
+return 0xFF;
+}
+
+
+void base64_decode(const char *encoded_string, FILE *FOut)
+{
+int in_len = strlen(encoded_string);
+int i = 0;
+int in_ = 0;
+uint8_t char_array_4[4], char_array_3[3];
+
+  while(in_len-- && (encoded_string[in_]!='=') && is_base64(encoded_string[in_])) 
+    {
+    char_array_4[i++] = FindBase64(encoded_string[in_++]);
+
+    if(i==4) 
+      {
+      char_array_3[0] = (char_array_4[0] << 2) + ((char_array_4[1] & 0x30) >> 4);
+      char_array_3[1] = ((char_array_4[1] & 0xf) << 4) + ((char_array_4[2] & 0x3c) >> 2);
+      char_array_3[2] = ((char_array_4[2] & 0x3) << 6) + char_array_4[3];
+
+      fwrite(char_array_3,1,3,FOut);
+      i = 0;
+      }
+    }
+
+  if(i) 
+  {
+    memset(char_array_4+i, FindBase64(0), 4-i);
+
+    char_array_3[0] = (char_array_4[0] << 2) + ((char_array_4[1] & 0x30) >> 4);
+    char_array_3[1] = ((char_array_4[1] & 0xf) << 4) + ((char_array_4[2] & 0x3c) >> 2);
+    char_array_3[2] = ((char_array_4[2] & 0x3) << 6) + char_array_4[3];
+    
+    fwrite(&char_array_3, 1, i-1, FOut);
+  }
+
+  return;
+}
+
+
+/////////////////////////////////////////////////////////////////
+
+
 void TconvertedPass1_XML::SelectTranslator(const char *CharSet)
 {
 string translator;
