@@ -59,7 +59,7 @@ public:
 
   int ind_leftmargin;
   signed char Indent_Level;
-  WORD tabent_tabpos[TABPOS_COUNT];
+  uint16_t tabent_tabpos[TABPOS_COUNT];
 };
 
 
@@ -71,10 +71,10 @@ public:
 
   Percentor perc;
   long rownum;
-  BYTE LangCount;
+  uint8_t LangCount;
 
   TLinePass2 Lines[4];
-  WORD tabpos[TABPOS_COUNT];  
+  uint16_t tabpos[TABPOS_COUNT];  
 
   bool underline, illegal_argument, just_envir_closed;
 
@@ -197,8 +197,8 @@ void TconvertedPass2::ReadTableEntry(short n)
 #ifdef DEBUG
   fprintf(log,"\n#Read_TableEntry(%d) ",(int)n); fflush(log);
 #endif
-WORD w;
-BYTE b;
+uint16_t w;
+uint8_t b;
 int j;
 TLinePass2 *pCurLine;
 
@@ -333,6 +333,7 @@ string TeX_RelativeFigDir;
     if(EndNotes>=1) fprintf(this->LaTeX, ",endnotes");
     if(Cyrillic>=1) fprintf(this->LaTeX, ",cyrillic");
     if(cjHebrew>=1) fprintf(this->LaTeX, ",cjhebrew");
+    if(mxedruli>=1) fprintf(this->LaTeX, ",mxedruli");
     if(InputPS==(IMG_InputPS|1))  fprintf(this->LaTeX, ",InputPS");
     if(InputPS==(IMG_graphicx|1)) fprintf(this->LaTeX, ",graphicx");
     if(InputPS==(IMG_epsfig|1))   fprintf(this->LaTeX, ",epsfig");
@@ -389,6 +390,7 @@ string TeX_RelativeFigDir;
     if(colors>=1)   UsePackage("color");
     if(Cyrillic>=1) UsePackage("cyrillic");
     if(cjHebrew>=1) UsePackage("cjhebrew");
+    if(mxedruli>=1) UsePackage("mxedruli");
     if(EndNotes>=1) UsePackage("endnotes");
     if(InputPS==(IMG_InputPS|1))  UsePackage("InputPS");
     if(InputPS==(IMG_graphicx|1)) UsePackage("graphicx");
