@@ -26,7 +26,7 @@
 
 #include "wp2latex.h"
 #include "struct.h"
-#include "images/raster.h"
+#include "images/image.h"
 #include "images/img_futi.h"
 
 #ifdef __BORLANDC__
@@ -78,7 +78,7 @@ Flags:'h';       Hard return
 		  1 Valid character placed on the line */
 
 /*WP2LaTex switches: -1:disabled; 0:automatically enabled; 1: forced to enable*/
-SBYTE   Accents = STYLE_NOTUSED,
+int8_t   Accents = STYLE_NOTUSED,
 	AmsMath = -1,
         Amssymb = -1,		// Totaly Disabled
 	Arevmath = -1,		// Totaly Disabled
@@ -105,6 +105,7 @@ SBYTE   Accents = STYLE_NOTUSED,
 	SaveWPG = -1,
         Rotate = STYLE_NOTUSED,
         Scalerel = STYLE_NOTUSED,
+        mxedruli = STYLE_NOTUSED,
 	LineNo = STYLE_NOTUSED;
 bool Index = false,
         Interactive = true,
@@ -185,6 +186,7 @@ const TStyleOpCl StyleOpCl2[] =
   {"\\cyr ", "", NULL, NULL},
   {"\\begin{cjhebrew}", "\\end{cjhebrew}", NULL, NULL},
   {"\\begin{linenumbers}", "\\end{linenumbers}", NULL, NULL},
+  {"\\mxedc ", "", NULL, NULL},
 };
 
 
@@ -221,6 +223,7 @@ const TStyleOpCl StyleOpCl3[] =
   {"\\cyr ", "", NULL, NULL},
   {"\\begin{cjhebrew}", "\\end{cjhebrew}", NULL, NULL},
   {"\\begin{linenumbers}", "\\end{linenumbers}", NULL, NULL},
+  {"\\mxedc ", "", NULL, NULL},
 };
 
 
@@ -556,8 +559,8 @@ NoHTML:
 /// This procedure provides autodetection of MTEF format.
 static int DetectMTEF(FILE *stream, FFormatDetect & iFFD)
 {
-DWORD Version,ObjLen,ThisFileSize;
-WORD HdrLen;
+uint32_t Version,ObjLen,ThisFileSize;
+uint16_t HdrLen;
 
   iFFD.DocumentType = "MTEF";
   iFFD.Converter = iFFD.DocumentType;
@@ -578,7 +581,7 @@ WORD HdrLen;
   if(ObjLen+HdrLen!=ThisFileSize) goto NoMTEF;	//wrong overall size
 
   fseek(stream,HdrLen+3,SEEK_SET);
-  RdWORD_HiEnd((WORD *)&iFFD.DocVersion,stream);
+  RdWORD_HiEnd((uint16_t *)&iFFD.DocVersion,stream);
 
   fseek(stream,HdrLen,SEEK_SET);
   return(1);			// Beware to seek offset!
@@ -592,7 +595,7 @@ NoMTEF:
 /** This procedure provides autodetection of postscript text. */
 static int DetectPostScript(FILE *stream, FFormatDetect & iFFD)
 {
-WORD Magic1,Magic2;
+uint16_t Magic1,Magic2;
 
   iFFD.DocumentType="PostScript file";
   iFFD.Extension = iFFD.Converter = "PS";
@@ -677,7 +680,7 @@ NoT602:
 /** This procedure provides autodetection of windows metafile. */
 static int DetectWinMetafile(FILE *stream, FFormatDetect & iFFD)
 {
-DWORD Magic1,Magic2;
+uint32_t Magic1,Magic2;
 
   iFFD.DocumentType = "Windows Metafile";
   iFFD.Extension = iFFD.Converter = "WMF";
@@ -897,7 +900,7 @@ XML_Detected:
 /** This procedure provides autodetection of OLE stream wrapper format. */
 static int DetectOLEStream(FILE *stream, FFormatDetect & iFFD)
 {
-DWORD Magic1,Magic2;
+uint32_t Magic1,Magic2;
 
   iFFD.DocumentType = "OLE Stream (might be Word or encapsulated WP)";
   iFFD.Converter = "OLE Stream";
@@ -948,7 +951,7 @@ int Status, CharNo=0, chr;
 
   Status=0;
   fseek(text,0,SEEK_SET);
-  while(CharNo<MaxChar)
+  while(CharNo<1024)		// SVG header might be very big with comments.
 	{
 	if( (chr=fgetc(text)) == EOF) goto NoSVG;
 	chr=toupper(chr);
@@ -958,7 +961,7 @@ int Status, CharNo=0, chr;
 		case 0:if(isspace(chr)) break;
 		       if(chr=='<') {Status=1;break;}
 		       goto NoSVG;
-		case 1:if(chr=='!') {Status=101;break;}	// ?xml
+		case 1:if(chr=='!') {Status=101;break;}	// !-- comment
 		       if(chr=='?') {Status=101;break;}	// ?xml
 		       if(chr=='S') {Status=2;break;}	// HTML tag
 		       if(chr=='M') {Status=7;break;}	// META tag
@@ -1009,8 +1012,8 @@ NoSVG:
 /// This procedure provides autodetection of unicode plain text.
 static int DetectUnicode(FILE *stream, FFormatDetect & iFFD)
 {
-WORD Magic1;
-BYTE Magic2,Check3;
+uint16_t Magic1;
+uint8_t Magic2,Check3;
   Rd_word(stream, &Magic1);
   Magic2=fgetc(stream);
   Check3=fgetc(stream);
@@ -1045,10 +1048,10 @@ BYTE Magic2,Check3;
  * For WORD>=8.x thich check inner OLE file  */
 int DetectWord(FILE *f, FFormatDetect & iFFD)
 {
-WORD wIdent;			/* 0x0000 */
-WORD nFib;			/* 0x0002 */
+uint16_t wIdent;			/* 0x0000 */
+uint16_t nFib;			/* 0x0002 */
 long CurrentPos;
-DWORD cbMac=0xFFFF;
+uint32_t cbMac=0xFFFF;
 
   iFFD.DocumentType="Microsoft Word";
   iFFD.Converter = "WORD";
@@ -1104,15 +1107,15 @@ DWORD cbMac=0xFFFF;
 
 
 				/*(4,5,3,3,3,3,4,4,4,5,5,6,6,8,8,0);*/
-BYTE ObjWP6SizesF0[0x10] = {4, 5, 3, 3, 3, 3, 4, 4, 4, 5, 5, 6, 6, 8, 8, 0};
+uint8_t ObjWP6SizesF0[0x10] = {4, 5, 3, 3, 3, 3, 4, 4, 4, 5, 5, 6, 6, 8, 8, 0};
 
 /* Checks whether the given document is a valid  WP5.x or WP6.x - document.
  * return: int: 0 if OK, else error code  */
 int DetectWordPerfect(FILE *wpd, FFormatDetect & iFFD)
 {
-DWORD id;
-WORD filetype, ver, encryption, dmp3;
-DWORD StartDoc;
+uint32_t id;
+uint16_t filetype, ver, encryption, dmp3;
+uint32_t StartDoc;
 long FilePos;
 
   iFFD.Converter = NULL;
@@ -1183,7 +1186,8 @@ long FilePos;
 	case 0x2C:iFFD.DocumentType="Macintosh WP2,3.x document";
                   switch(ver & 0xFF)
                   {
-	            case 1: fprintf(err,_("\nWarning: Unknown MAC WP version 0x%x. Guessing WP%u.%u. EXPECT ERRORS!!! Please report."),ver,ver&0xFF,ver>>8);
+	            case 1: if(err)
+                                fprintf(err,_("\nWarning: Unknown MAC WP version 0x%x. Guessing WP%u.%u. EXPECT ERRORS!!! Please report."),ver,ver&0xFF,ver>>8);
                     case 2: 	/*   version == MAC 2 -> WP 3.x  */
                     case 3: 	/*   version == MAC 3 -> WP 3.x  */
                     case 4: 	/*   version == MAC 4 -> WP MAC4.x  */
@@ -1214,7 +1218,7 @@ long FilePos;
     if(filetype==0x3A01)
         {
     	iFFD.DocumentStart = StartDoc;
-        iFFD.DocVersion=0x500 + (WORD)(ver>>8);
+        iFFD.DocVersion=0x500 + (uint16_t)(ver>>8);
         iFFD.Converter = "WP5.FarEast";
         }
 
@@ -1228,11 +1232,11 @@ long FilePos;
          iFFD.DocumentStart = StartDoc;
          switch(ver & 0xFF)  // major version
 	   {
-	   case 0:iFFD.DocVersion=0x500 + (WORD)(ver>>8);
+	   case 0:iFFD.DocVersion=0x500 + (uint16_t)(ver>>8);
 		  if(encryption==0) iFFD.Converter="WP5.x";
 			       else iFFD.Converter="WP5.x encrypted";
 		  break;
-	   case 2:iFFD.DocVersion=0x600 + (WORD)(ver>>8);
+	   case 2:iFFD.DocVersion=0x600 + (uint16_t)(ver>>8);
 		  if(iFFD.DocVersion>=0x602) iFFD.DocVersion+=0xFE;
 		  if(encryption==0) iFFD.Converter="WP6.x";
 		  else
@@ -1241,7 +1245,7 @@ long FilePos;
 		    fprintf(err,_(EncryptionWarning));
 		    }
 		  break;
-	   default:iFFD.DocVersion=0x500l + (WORD)(ver>>8) + 256*(ver & 0xFF);
+	   default:iFFD.DocVersion=0x500l + (uint16_t)(ver>>8) + 256*(ver & 0xFF);
 		   iFFD.Converter="WP6.x";	/* Place here -FORCE warning */
 		   fprintf(err,_("\nWarning: Unknown WP version 0x%x. Guessing WP%u.%u. EXPECT ERRORS!!! Please report."),ver,iFFD.DocVersion>>8,iFFD.DocVersion & 0xFF);
 		   if(encryption!=0) fprintf(err,_(EncryptionWarning));
@@ -1268,7 +1272,7 @@ return 0;
 }
 
 
-BYTE ObjWP4SizesC0[]=
+uint8_t ObjWP4SizesC0[] =
 	{6,  4,  3,  5,  5,  6,  4,  6,  8, 42,  3,  6,  4,  3,  4,  3,
 	 6,  0,  0,  4,  4,  4,  6, 65,  4,  4,  4,  4,  9, 24,  4,  0,
 //                                  ^0                  ^0
@@ -1277,7 +1281,7 @@ BYTE ObjWP4SizesC0[]=
 	 6,106,  0,100,  4,  0,  5,  0,  0,  0,  0,  0,  0,  0,  0,  0};
 
 
-BYTE ObjWP1SizesC0[]=
+uint8_t ObjWP1SizesC0[]=
 	{10, 4,  4,  7,  7,  6,  4,  6,  8,  0,  3,  6,  6,  3,  6,  3,
 	 6,  0,  0,  4,  4,  4,  6,  0,  4,  4,  4,  4,  0, 24,  6,  0,
 	 4,  3,  0,150,  6, 23, 11,  3,  3,  0,  0, 32,  5,  0, 44, 18,
@@ -1285,10 +1289,10 @@ BYTE ObjWP1SizesC0[]=
 
 
 /** Common detection procedure for both WP1Mac and WP4PC. */
-static int DetectWP1and4(FILE *wpd, BYTE *ObjWPxSizesC0)
+static int DetectWP1and4(FILE *wpd, const uint8_t *ObjWPxSizesC0)
 {
 long FilePos;
-BYTE w,Flag;
+uint8_t w,Flag;
 int WP_hit;
 unsigned CharNo;
 
@@ -1298,7 +1302,7 @@ unsigned CharNo;
   CharNo = 0;
   while(!feof(wpd) && CharNo<MaxChar)
      {
-     const BYTE c = fgetc(wpd);	CharNo++;
+     const uint8_t c = fgetc(wpd);	CharNo++;
 //   printf("[%X %X]",ftell(wpd),c);
 
      if(c>=0xC0)
@@ -1325,7 +1329,7 @@ unsigned CharNo;
 	   WP_hit+=Flag;
 	   if(WP_hit>2)		//attempt to cut autodetection block
 	     {
-	     if(ObjWP4SizesC0[c-0xC0]!=ObjWP1SizesC0[c-0xC0])
+	     if(ObjWP4SizesC0[c-0xC0] != ObjWP1SizesC0[c-0xC0])
 		break;	//more than 2 special WP keywords found
 	     }
 	   }
@@ -1526,7 +1530,7 @@ return 1;
 typedef struct
 {
   const char *Name;
-  SBYTE      *Flag;
+  int8_t      *Flag;
   const char *Description;
 } PkgItem;
 
@@ -1557,6 +1561,7 @@ static const PkgItem PkgList[] =
         {"LongTable",&LongTable, N_("Use longtable for better tables.")},
         {"makeidx",&MakeIdx,NULL},   
         {"MakeIdx",&MakeIdx, N_("Use makeidx for placing index.")},
+        {"mxedruli",&mxedruli, N_("Use mxedruli for Georgia characters.")},
         {"pifont",&pifont,NULL},
         {"PiFont",&pifont, N_("Use additional package pifont.")},
         {"rsfs",&Rsfs,NULL},
@@ -1570,7 +1575,7 @@ static const PkgItem PkgList[] =
         {"Wasy",&Wasy,N_("Use Wasy2 with special characters.")}};
 
 
-static char StyleUsed(SBYTE *u)
+static char StyleUsed(int8_t *u)
 {
   if(u==NULL) return ' ';
   if(*u<=-1) return '-';
