@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"3.113"
-#define VersionDate	"10 Jun 2023"  /* day (space) month (space) full year */
+#define VersionWP2L	"4.2"
+#define VersionDate	"28 Sep 2023"  /* day (space) month (space) full year */
 
 
 /* Constants for a flag InputPS */
@@ -33,10 +33,10 @@ typedef enum
 extern unsigned short OutCodePage, WPcharset;
 extern bool Index, Interactive, NFSS, TABs, twoside, ExactFnNumbers, CPStyles,
 	 EraseStrip, UndoRedo, Noclobber;
-extern SBYTE Cyrillic, colors, EndNotes, FancyHdr, Columns, cjHebrew, InputPS, MakeIdx,
+extern int8_t Cyrillic, colors, EndNotes, FancyHdr, Columns, cjHebrew, InputPS, MakeIdx,
 	 textcomp, Wasy, Accents, Amssymb, Arevmath, LaTeXsym, LongTable, Bbm, TIPA, fontenc,
 	 Rsfs, Ulem, pifont, PostScript, rus_yo, Rotate, Scalerel, LineNo, AmsMath,
-         SaveWPG;
+         SaveWPG, mxedruli;
 extern int LaTeX_Version;
 extern signed char Verbosing;
 extern bool TexChars,ExtendedCheck,OptimizeSection,FixSpaces;
@@ -49,9 +49,9 @@ typedef struct			/* Auto detection structure for file formats */
 	const char *DocumentType;
 	const char *Converter;	///< ASCII key for looking converter module.
         const char *Extension;
-	WORD DocVersion;
+	uint16_t DocVersion;
 	float Probability;	///< <-1 surely not  0 don't know  1 surely yes>
-        DWORD DocumentStart;
+        uint32_t DocumentStart;
 	} FFormatDetect;
 extern FFormatDetect FilForD;
 
@@ -64,6 +64,7 @@ extern long num_of_lines_stripfile;
 #define Cyr_Font	  27
 #define Heb_Font	  28
 #define Line_Num	  29
+#define Georgia_Font	  30
 extern int OutputStyle;
 
 
@@ -96,11 +97,13 @@ int CopyFile(const char *Dest, const char *Src);
 int CopyFile(const char *Dest, FILE *in, long size);
 int CopyFile(FILE *out, FILE *in, long size);
 
-DWORD ch_fgetc(FILE *F);
-DWORD w_fgetc(FILE *F);
-DWORD W_fgetc(FILE *F);
+uint32_t ch_fgetc(FILE *F);
+uint32_t w_fgetc(FILE *F);
+uint32_t W_fgetc(FILE *F);
 
 
+//struct RGBQuad;
+
 void LoadConfigFile(const char *filename);
 int CheckFileFormat(FILE *wpd,FFormatDetect & FilForD);
 
@@ -155,19 +158,19 @@ typedef enum
 
 typedef struct
 	{
-	BYTE  AnchorType;	//< 0-Paragraph, 1-Page, 2-Character
-	BYTE  HorizontalPos;    //< 0-Left, 1-Right, 2-Center, 3-Full
-	BYTE  Contents;		//< 1-text, 2-disk image, 3-buildin image, 4-equation
-	BYTE  Type;
+	uint8_t  AnchorType;	//< 0-Paragraph, 1-Page, 2-Character
+	uint8_t  HorizontalPos;    //< 0-Left, 1-Right, 2-Center, 3-Full
+	uint8_t  Contents;		//< 1-text, 2-disk image, 3-buildin image, 4-equation
+	uint8_t  Type;
 	float Width;		//< Expected width of image in [mm] ?? or [cm]??, or <=0 when unknown.
 	float VScale;
 	float HScale;
-	WORD RotAngle;		//< Rotation in degrees
-	WORD  CaptionSize;
-	DWORD CaptionPos;
-	SBYTE Image_type;	//< 0-external, 1-buildin WPG1, 2-buildin WPG2
-	DWORD Image_offset;     //< Ofset of embedded image blob in a host file.
-	DWORD Image_size;	//< Size of embedded image blob.
+	uint16_t RotAngle;		//< Rotation in degrees
+	uint16_t  CaptionSize;
+	uint32_t CaptionPos;
+	int8_t Image_type;	//< 0-external, 1-buildin WPG1, 2-buildin WPG2
+	uint32_t Image_offset;     //< Ofset of embedded image blob in a host file.
+	uint32_t Image_size;	//< Size of embedded image blob.
 	} TBox;
 
 
@@ -205,7 +208,7 @@ public:
   virtual ~TconvertedPass1()	{}
 
   Percentor perc;
-  DWORD DocumentStart;
+  uint32_t DocumentStart;
   attribute attr;
 
   char indenting;
@@ -219,15 +222,15 @@ public:
   char envir, line_term;
 
   int num_of_tabs, latex_tabpos;
-  WORD tabpos[TAB_POS_SIZE];
+  uint16_t tabpos[TAB_POS_SIZE];
   char tab_type;
 
   int WP_sidemargin,Lmar,Rmar;
 
-  WORD ind_leftmargin, ind_rightmargin;
+  uint16_t ind_leftmargin, ind_rightmargin;
 
   unsigned char by, subby;
-  DWORD ActualPos;
+  uint32_t ActualPos;
 
   unsigned rownum;
 
@@ -273,18 +276,11 @@ typedef enum
   FONT_NEUTRAL = 0,
   FONT_NORMAL = 1,
   FONT_CYRILLIC = 2,
-  FONT_HEBREW = 3
+  FONT_HEBREW = 3,
+  FONT_GEORGIA = 4
 } FontTypes;
 
 
-#ifndef RGBQuad_DEFINED
-#define RGBQuad_DEFINED
-struct RGBQuad
-	{
-	unsigned R,G,B,O;
-	};
-#endif
-
 /* Variables for Convert_second_pass: */
 /*  .... only in pass2.cc ...  */
 
@@ -294,7 +290,7 @@ struct RGBQuad
 #define KOI8R		8
 #define UTF8		16384
 
-const char *Ext_chr_str(WORD char_code, TconvertedPass1 *cq, const CpTranslator *ConvertCP=NULL);
+const char *Ext_chr_str(uint16_t char_code, TconvertedPass1 *cq, const CpTranslator *ConvertCP=NULL);
 
 typedef enum {aExtraLarge=0, aVeryLarge1=1, aLarge=2, aSmall=3, aFine=4,
 	      aSupscript=5, aSubscript=6, aOutline=7, aItalic=8, aShadow=9,
@@ -315,7 +311,9 @@ void CellTable(TconvertedPass1 *cq);
 void Center(TconvertedPass1 *cq);
 void CenterPage(TconvertedPass1 *cq);
 void CharacterStr(TconvertedPass1 *cq,const char *LatexCode);
+#ifdef __Rasters_h
 void Color(TconvertedPass1 *cq, signed char WP, RGBQuad *RGB=NULL);
+#endif
 void Column(TconvertedPass1 *cq,signed char number);
 void DateCode(TconvertedPass1 *cq);
 void End_of_indent(TconvertedPass1 *cq);
@@ -331,12 +329,11 @@ void initBox(TBox &Box);
 void InitHeaderFooter(TconvertedPass1 *cq, char HorF, char occurance);
 void InvisibleSoftReturn(TconvertedPass1 *cq);
 void Justification(TconvertedPass1 *cq, unsigned char WPx);
-void Language(TconvertedPass1 *cq, WORD WPx_Language);
-void LineNumbering(TconvertedPass1 *cq, BYTE LineNumbering);
+void Language(TconvertedPass1 *cq, uint16_t WPx_Language);
+void LineNumbering(TconvertedPass1 *cq, uint8_t LineNumbering);
 void PageNumber(TconvertedPass1 *cq);
 void PlaceEndnotes(TconvertedPass1 *cq);
 void PlaceIndex(TconvertedPass1 *cq);
-//void PutCharacter(TconvertedPass1 *cq,char *CharStr);
 void EndSection(TconvertedPass1 *cq, signed char WP);
 void Page_number_position(TconvertedPass1 *cq, unsigned char WP);
 void ParagraphNumber(TconvertedPass1 *cq);
@@ -364,7 +361,7 @@ void Convert_second_pass(FILE *Strip,FILE *table, FILE *FileOut, FILE *log, FILE
 
 
 /* global functions of formulas.cc */
-void AnyBox(TconvertedPass1 *cq, DWORD end_of_code);
+void AnyBox(TconvertedPass1 *cq, uint32_t end_of_code);
 void BoxTexFoot(TconvertedPass1 *cq, const TBox & Box);
 #ifdef __Stringa_h
  char Remove1stArg(string & str,string & arg);
@@ -463,9 +460,9 @@ public: explicit FFormatTranslator(const char *NewShortKey, Factory_Pass1 NewCon
 typedef struct
 {
    char LangShort[2];		///< Language abbreviation
-   BYTE WP3LangId;
+   uint8_t WP3LangId;
    const char *LangDesc;	///< LaTeX Language description
-   SBYTE      UseLang;
+   int8_t  UseLang;
 } LangItem;
 
 extern LangItem LangTable[31];
@@ -485,7 +482,7 @@ extern LangItem LangTable[31];
 #endif
 
 #ifdef __Stringa_h  //Only Strings related stuff
-temp_string Attributes2String(DWORD Attributes);
+temp_string Attributes2String(uint32_t Attributes);
 temp_string MergePaths(const string & Path, const string & RelPath, bool EnsureTrail=true);
 void PutFormula(TconvertedPass1 *cq, char *Str,const TBox & Box);
 extern string RelativeFigDir, OutputDir;
@@ -542,7 +539,7 @@ typedef struct
 {
   const char	*Name;
   const char    *Translator;
-  WORD		Id;
+  uint16_t		Id;
   bool		UseCpStyles;
 } TOutCodePage;
 
@@ -550,7 +547,7 @@ extern const TOutCodePage OutCodepages[11];
 
 
 #ifndef FINAL
-void CrackObject(TconvertedPass1 *cq, DWORD end_of_code);
+void CrackObject(TconvertedPass1 *cq, uint32_t end_of_code);
 #endif
 
 #ifdef __cplusplus
@@ -558,7 +555,7 @@ extern "C" {
 #endif
 
 /* functions from utf8.c */
-DWORD utf8_fgetc(FILE *F);
+uint32_t utf8_fgetc(FILE *F);
 #ifdef __cplusplus
 }
 #endif
@@ -581,5 +578,4 @@ typedef enum
 
 
 
-
 #endif
